import { openBlock, createElementBlock, renderSlot, createElementVNode, Fragment, renderList, normalizeClass, createCommentVNode, withModifiers, h, resolveComponent, createBlock, withCtx, createTextVNode, toDisplayString, createVNode, Teleport, withDirectives, vShow, normalizeStyle, resolveDirective, withKeys, vModelText, normalizeProps, mergeProps, render as render$s, createSlots, vModelDynamic, reactive } from 'vue';

// https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/assign#Polyfill
function assign(target, varArgs) {
  var arguments$1 = arguments;

  if (target === null || target === undefined) {
    throw new TypeError('Cannot convert undefined or null to object')
  }
  var to = Object(target);
  for (var index = 1; index < arguments.length; index++) {
    var nextSource = arguments$1[index];
    if (nextSource !== null && nextSource !== undefined) {
      for (var nextKey in nextSource) {
        // Avoid bugs when hasOwnProperty is shadowed
        /* istanbul ignore else */
        if (Object.prototype.hasOwnProperty.call(nextSource, nextKey)) {
          to[nextKey] = nextSource[nextKey];
        }
      }
    }
  }
  return to
}

function isExist(obj) {
  return typeof obj !== 'undefined' && obj !== null
}

function isFunction(obj) {
  return typeof obj === 'function'
}

function isNumber(obj) {
  return typeof obj === 'number'
}

function isString(obj) {
  return typeof obj === 'string'
}

function isBoolean(obj) {
  return typeof obj === 'boolean'
}

function isPromiseSupported() {
  return typeof window !== 'undefined' && isExist(window.Promise)
}

function hasOwnProperty(o, k) {
  return Object.prototype.hasOwnProperty.call(o, k)
}

var script$u = {
  props: {
    modelValue: {
      type: Number,
      default: undefined,
    },
    indicators: {
      type: Boolean,
      default: true,
    },
    controls: {
      type: Boolean,
      default: true,
    },
    interval: {
      type: Number,
      default: 5000,
    },
    iconControlLeft: {
      type: String,
      default: 'glyphicon glyphicon-chevron-left',
    },
    iconControlRight: {
      type: String,
      default: 'glyphicon glyphicon-chevron-right',
    },
  },
  emits: ['update:modelValue', 'change'],
  data: function data() {
    return {
      slides: [],
      activeIndex: 0, // Make v-model not required
      timeoutId: 0,
      intervalId: 0,
    }
  },
  watch: {
    interval: function interval() {
      this.startInterval();
    },
    modelValue: function modelValue(index, oldValue) {
      this.run(index, oldValue);
      this.activeIndex = index;
    },
  },
  mounted: function mounted() {
    if (isExist(this.modelValue)) {
      this.activeIndex = this.modelValue;
    }
    if (this.slides.length > 0) {
      this.$select(this.activeIndex);
    }
    this.startInterval();
  },
  beforeUnmount: function beforeUnmount() {
    this.stopInterval();
  },
  methods: {
    run: function run(newIndex, oldIndex) {
      var this$1$1 = this;

      var currentActiveIndex = oldIndex || 0;
      var direction;
      if (newIndex > currentActiveIndex) {
        direction = ['next', 'left'];
      } else {
        direction = ['prev', 'right'];
      }
      this.slides[newIndex].slideClass[direction[0]] = true;
      this.$nextTick(function () {
        this$1$1.slides[newIndex].$el.offsetHeight;
        this$1$1.slides.forEach(function (slide, i) {
          if (i === currentActiveIndex) {
            slide.slideClass.active = true;
            slide.slideClass[direction[1]] = true;
          } else if (i === newIndex) {
            slide.slideClass[direction[1]] = true;
          }
        });
        this$1$1.timeoutId = setTimeout(function () {
          this$1$1.$select(newIndex);
          this$1$1.$emit('change', newIndex);
          this$1$1.timeoutId = 0;
        }, 600);
      });
    },
    startInterval: function startInterval() {
      var this$1$1 = this;

      this.stopInterval();
      if (this.interval > 0) {
        this.intervalId = setInterval(function () {
          this$1$1.next();
        }, this.interval);
      }
    },
    stopInterval: function stopInterval() {
      clearInterval(this.intervalId);
      this.intervalId = 0;
    },
    resetAllSlideClass: function resetAllSlideClass() {
      this.slides.forEach(function (slide) {
        slide.slideClass.active = false;
        slide.slideClass.left = false;
        slide.slideClass.right = false;
        slide.slideClass.next = false;
        slide.slideClass.prev = false;
      });
    },
    $select: function $select(index) {
      this.resetAllSlideClass();
      this.slides[index].slideClass.active = true;
    },
    select: function select(index) {
      if (this.timeoutId !== 0 || index === this.activeIndex) {
        return
      }
      if (isExist(this.modelValue)) {
        this.$emit('update:modelValue', index);
      } else {
        this.run(index, this.activeIndex);
        this.activeIndex = index;
      }
    },
    prev: function prev() {
      this.select(
        this.activeIndex === 0 ? this.slides.length - 1 : this.activeIndex - 1
      );
    },
    next: function next() {
      this.select(
        this.activeIndex === this.slides.length - 1 ? 0 : this.activeIndex + 1
      );
    },
  },
};

var _hoisted_1$l = { class: "carousel-indicators" };
var _hoisted_2$f = ["onClick"];
var _hoisted_3$b = {
  class: "carousel-inner",
  role: "listbox"
};
var _hoisted_4$a = /*#__PURE__*/createElementVNode("span", { class: "sr-only" }, "Previous", -1 /* HOISTED */);
var _hoisted_5$8 = /*#__PURE__*/createElementVNode("span", { class: "sr-only" }, "Next", -1 /* HOISTED */);

function render$r(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("div", {
    class: "carousel slide",
    "data-ride": "carousel",
    onMouseenter: _cache[2] || (_cache[2] = function () {
      var args = [], len = arguments.length;
      while ( len-- ) args[ len ] = arguments[ len ];

      return ($options.stopInterval && $options.stopInterval.apply($options, args));
  }),
    onMouseleave: _cache[3] || (_cache[3] = function () {
      var args = [], len = arguments.length;
      while ( len-- ) args[ len ] = arguments[ len ];

      return ($options.startInterval && $options.startInterval.apply($options, args));
  })
  }, [
    ($props.indicators)
      ? renderSlot(_ctx.$slots, "indicators", {
          key: 0,
          select: $options.select,
          activeIndex: $data.activeIndex
        }, function () { return [
          createElementVNode("ol", _hoisted_1$l, [
            (openBlock(true), createElementBlock(Fragment, null, renderList($data.slides, function (slide, index) {
              return (openBlock(), createElementBlock("li", {
                key: index,
                class: normalizeClass({ active: index === $data.activeIndex }),
                onClick: function ($event) { return ($options.select(index)); }
              }, null, 10 /* CLASS, PROPS */, _hoisted_2$f))
            }), 128 /* KEYED_FRAGMENT */))
          ])
        ]; })
      : createCommentVNode("v-if", true),
    createElementVNode("div", _hoisted_3$b, [
      renderSlot(_ctx.$slots, "default")
    ]),
    ($props.controls)
      ? (openBlock(), createElementBlock("a", {
          key: 1,
          class: "left carousel-control",
          href: "#",
          role: "button",
          onClick: _cache[0] || (_cache[0] = withModifiers(function ($event) { return ($options.prev()); }, ["prevent"]))
        }, [
          createElementVNode("span", {
            class: normalizeClass($props.iconControlLeft),
            "aria-hidden": "true"
          }, null, 2 /* CLASS */),
          _hoisted_4$a
        ]))
      : createCommentVNode("v-if", true),
    ($props.controls)
      ? (openBlock(), createElementBlock("a", {
          key: 2,
          class: "right carousel-control",
          href: "#",
          role: "button",
          onClick: _cache[1] || (_cache[1] = withModifiers(function ($event) { return ($options.next()); }, ["prevent"]))
        }, [
          createElementVNode("span", {
            class: normalizeClass($props.iconControlRight),
            "aria-hidden": "true"
          }, null, 2 /* CLASS */),
          _hoisted_5$8
        ]))
      : createCommentVNode("v-if", true)
  ], 32 /* HYDRATE_EVENTS */))
}

script$u.render = render$r;
script$u.__file = "src/components/carousel/Carousel.vue";

function spliceIfExist(arr, item) {
  if (Array.isArray(arr)) {
    var index = arr.indexOf(item);
    if (index >= 0) {
      arr.splice(index, 1);
    }
  }
}

function range(end, start, step) {
  if ( start === void 0 ) start = 0;
  if ( step === void 0 ) step = 1;

  var arr = [];
  for (var i = start; i < end; i += step) {
    arr.push(i);
  }
  return arr
}

function nodeListToArray(nodeList) {
  return Array.prototype.slice.call(nodeList || [])
}

function onlyUnique(value, index, self) {
  return self.indexOf(value) === index
}

var script$t = {
  data: function data() {
    return {
      slideClass: {
        active: false,
        prev: false,
        next: false,
        left: false,
        right: false,
      },
    }
  },
  created: function created() {
    try {
      this.$parent.slides.push(this);
    } catch (e) {
      throw new Error('Slide parent must be Carousel.')
    }
  },
  beforeUnmount: function beforeUnmount() {
    var slides = this.$parent && this.$parent.slides;
    spliceIfExist(slides, this);
  },
};

function render$q(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("div", {
    class: normalizeClass(["item", $data.slideClass])
  }, [
    renderSlot(_ctx.$slots, "default")
  ], 2 /* CLASS */))
}

script$t.render = render$q;
script$t.__file = "src/components/carousel/Slide.vue";

var EVENTS = {
  MOUSE_ENTER: 'mouseenter',
  MOUSE_LEAVE: 'mouseleave',
  MOUSE_DOWN: 'mousedown',
  MOUSE_UP: 'mouseup',
  FOCUS: 'focus',
  BLUR: 'blur',
  CLICK: 'click',
  INPUT: 'input',
  KEY_DOWN: 'keydown',
  KEY_UP: 'keyup',
  KEY_PRESS: 'keypress',
  RESIZE: 'resize',
  SCROLL: 'scroll',
  TOUCH_START: 'touchstart',
  TOUCH_END: 'touchend',
};

var TRIGGERS = {
  CLICK: 'click',
  HOVER: 'hover',
  FOCUS: 'focus',
  HOVER_FOCUS: 'hover-focus',
  OUTSIDE_CLICK: 'outside-click',
  MANUAL: 'manual',
};

var PLACEMENTS$1 = {
  TOP: 'top',
  RIGHT: 'right',
  BOTTOM: 'bottom',
  LEFT: 'left',
};

function isIE11() {
  /* istanbul ignore next */
  return !!window.MSInputMethodContext && !!document.documentMode
}

function isIE10() {
  return window.navigator.appVersion.indexOf('MSIE 10') !== -1
}

function getComputedStyle(el) {
  return window.getComputedStyle(el)
}

function getViewportSize() {
  /* istanbul ignore next */
  var width =
    Math.max(document.documentElement.clientWidth, window.innerWidth) || 0;
  /* istanbul ignore next */
  var height =
    Math.max(document.documentElement.clientHeight, window.innerHeight) || 0;
  return { width: width, height: height }
}

var scrollbarWidth = null;
var savedScreenSize = null;

function getScrollbarWidth(recalculate) {
  if ( recalculate === void 0 ) recalculate = false;

  var screenSize = getViewportSize();
  // return directly when already calculated & not force recalculate & screen size not changed
  if (
    scrollbarWidth !== null &&
    !recalculate &&
    screenSize.height === savedScreenSize.height &&
    screenSize.width === savedScreenSize.width
  ) {
    return scrollbarWidth
  }
  /* istanbul ignore next */
  if (document.readyState === 'loading') {
    return null
  }
  var div1 = document.createElement('div');
  var div2 = document.createElement('div');
  div1.style.width =
    div2.style.width =
    div1.style.height =
    div2.style.height =
      '100px';
  div1.style.overflow = 'scroll';
  div2.style.overflow = 'hidden';
  document.body.appendChild(div1);
  document.body.appendChild(div2);
  scrollbarWidth = Math.abs(div1.scrollHeight - div2.scrollHeight);
  document.body.removeChild(div1);
  document.body.removeChild(div2);
  // save new screen size
  savedScreenSize = screenSize;
  return scrollbarWidth
}

function on(element, event, handler) {
  /* istanbul ignore next */
  element.addEventListener(event, handler);
}

function off(element, event, handler) {
  /* istanbul ignore next */
  element.removeEventListener(event, handler);
}

function isElement(el) {
  return el && el.nodeType === Node.ELEMENT_NODE
}

function removeFromDom(el) {
  isElement(el) && isElement(el.parentNode) && el.parentNode.removeChild(el);
}

function ensureElementMatchesFunction() {
  /* istanbul ignore next */
  if (!Element.prototype.matches) {
    Element.prototype.matches =
      Element.prototype.matchesSelector ||
      Element.prototype.mozMatchesSelector ||
      Element.prototype.msMatchesSelector ||
      Element.prototype.oMatchesSelector ||
      Element.prototype.webkitMatchesSelector ||
      function (s) {
        var matches = (this.document || this.ownerDocument).querySelectorAll(
          s
        );
        var i = matches.length;
        // eslint-disable-next-line no-empty
        while (--i >= 0 && matches.item(i) !== this) {}
        return i > -1
      };
  }
}

function addClass(el, className) {
  if (!isElement(el)) {
    return
  }
  if (el.className) {
    var classes = el.className.split(' ');
    if (classes.indexOf(className) < 0) {
      classes.push(className);
      el.className = classes.join(' ');
    }
  } else {
    el.className = className;
  }
}

function removeClass(el, className) {
  if (!isElement(el)) {
    return
  }
  if (el.className) {
    var classes = el.className.split(' ');
    var newClasses = [];
    for (var i = 0, l = classes.length; i < l; i++) {
      if (classes[i] !== className) {
        newClasses.push(classes[i]);
      }
    }
    el.className = newClasses.join(' ');
  }
}

function hasClass(el, className) {
  if (!isElement(el)) {
    return false
  }
  var classes = el.className.split(' ');
  for (var i = 0, l = classes.length; i < l; i++) {
    if (classes[i] === className) {
      return true
    }
  }
  return false
}

function setDropdownPosition(dropdown, trigger, options) {
  if ( options === void 0 ) options = {};

  var doc = document.documentElement;
  var containerScrollLeft =
    (window.pageXOffset || doc.scrollLeft) - (doc.clientLeft || 0);
  var containerScrollTop =
    (window.pageYOffset || doc.scrollTop) - (doc.clientTop || 0);
  var rect = trigger.getBoundingClientRect();
  var dropdownRect = dropdown.getBoundingClientRect();
  dropdown.style.right = 'auto';
  dropdown.style.bottom = 'auto';
  if (options.menuRight) {
    dropdown.style.left =
      containerScrollLeft + rect.left + rect.width - dropdownRect.width + 'px';
  } else {
    dropdown.style.left = containerScrollLeft + rect.left + 'px';
  }
  if (options.dropup) {
    dropdown.style.top =
      containerScrollTop + rect.top - dropdownRect.height - 4 + 'px';
  } else {
    dropdown.style.top = containerScrollTop + rect.top + rect.height + 'px';
  }
}

function isAvailableAtPosition(trigger, popup, placement) {
  var triggerRect = trigger.getBoundingClientRect();
  var popupRect = popup.getBoundingClientRect();
  var viewPortSize = getViewportSize();
  var top = true;
  var right = true;
  var bottom = true;
  var left = true;
  switch (placement) {
    case PLACEMENTS$1.TOP:
      top = triggerRect.top >= popupRect.height;
      left = triggerRect.left + triggerRect.width / 2 >= popupRect.width / 2;
      right =
        triggerRect.right - triggerRect.width / 2 + popupRect.width / 2 <=
        viewPortSize.width;
      break
    case PLACEMENTS$1.BOTTOM:
      bottom = triggerRect.bottom + popupRect.height <= viewPortSize.height;
      left = triggerRect.left + triggerRect.width / 2 >= popupRect.width / 2;
      right =
        triggerRect.right - triggerRect.width / 2 + popupRect.width / 2 <=
        viewPortSize.width;
      break
    case PLACEMENTS$1.RIGHT:
      right = triggerRect.right + popupRect.width <= viewPortSize.width;
      top = triggerRect.top + triggerRect.height / 2 >= popupRect.height / 2;
      bottom =
        triggerRect.bottom - triggerRect.height / 2 + popupRect.height / 2 <=
        viewPortSize.height;
      break
    case PLACEMENTS$1.LEFT:
      left = triggerRect.left >= popupRect.width;
      top = triggerRect.top + triggerRect.height / 2 >= popupRect.height / 2;
      bottom =
        triggerRect.bottom - triggerRect.height / 2 + popupRect.height / 2 <=
        viewPortSize.height;
      break
  }
  return top && right && bottom && left
}

function setTooltipPosition(
  tooltip,
  trigger,
  placement,
  auto,
  appendTo,
  positionBy,
  viewport
) {
  if (!isElement(tooltip) || !isElement(trigger)) {
    return
  }
  var isPopover =
    tooltip && tooltip.className && tooltip.className.indexOf('popover') >= 0;
  var containerScrollTop;
  var containerScrollLeft;
  if (!isExist(appendTo) || appendTo === 'body' || positionBy === 'body') {
    var doc = document.documentElement;
    containerScrollLeft =
      (window.pageXOffset || doc.scrollLeft) - (doc.clientLeft || 0);
    containerScrollTop =
      (window.pageYOffset || doc.scrollTop) - (doc.clientTop || 0);
  } else {
    var container = getElementBySelectorOrRef(positionBy || appendTo);
    containerScrollLeft = container.scrollLeft;
    containerScrollTop = container.scrollTop;
  }
  // auto adjust placement
  if (auto) {
    // Try: right -> bottom -> left -> top
    // Cause the default placement is top
    var placements = [
      PLACEMENTS$1.RIGHT,
      PLACEMENTS$1.BOTTOM,
      PLACEMENTS$1.LEFT,
      PLACEMENTS$1.TOP ];
    // The class switch helper function
    var changePlacementClass = function (placement) {
      // console.log(placement)
      placements.forEach(function (placement) {
        removeClass(tooltip, placement);
      });
      addClass(tooltip, placement);
    };
    // No need to adjust if the default placement fits
    if (!isAvailableAtPosition(trigger, tooltip, placement)) {
      for (var i = 0, l = placements.length; i < l; i++) {
        // Re-assign placement class
        changePlacementClass(placements[i]);
        // Break if new placement fits
        if (isAvailableAtPosition(trigger, tooltip, placements[i])) {
          placement = placements[i];
          break
        }
      }
      changePlacementClass(placement);
    }
  }
  // fix left and top for tooltip
  var rect = trigger.getBoundingClientRect();
  var tooltipRect = tooltip.getBoundingClientRect();
  var top;
  var left;
  if (placement === PLACEMENTS$1.BOTTOM) {
    top = containerScrollTop + rect.top + rect.height;
    left =
      containerScrollLeft + rect.left + rect.width / 2 - tooltipRect.width / 2;
  } else if (placement === PLACEMENTS$1.LEFT) {
    top =
      containerScrollTop + rect.top + rect.height / 2 - tooltipRect.height / 2;
    left = containerScrollLeft + rect.left - tooltipRect.width;
  } else if (placement === PLACEMENTS$1.RIGHT) {
    top =
      containerScrollTop + rect.top + rect.height / 2 - tooltipRect.height / 2;
    // https://github.com/uiv-lib/uiv/issues/272
    // add 1px to fix above issue
    left = containerScrollLeft + rect.left + rect.width + 1;
  } else {
    top = containerScrollTop + rect.top - tooltipRect.height;
    left =
      containerScrollLeft + rect.left + rect.width / 2 - tooltipRect.width / 2;
  }
  var viewportEl;
  // viewport option
  if (isString(viewport)) {
    viewportEl = document.querySelector(viewport);
  } else if (isFunction(viewport)) {
    viewportEl = viewport(trigger);
  }
  if (isElement(viewportEl)) {
    var popoverFix = isPopover ? 11 : 0;
    var viewportReact = viewportEl.getBoundingClientRect();
    var viewportTop = containerScrollTop + viewportReact.top;
    var viewportLeft = containerScrollLeft + viewportReact.left;
    var viewportBottom = viewportTop + viewportReact.height;
    var viewportRight = viewportLeft + viewportReact.width;
    // fix top
    if (top < viewportTop) {
      top = viewportTop;
    } else if (top + tooltipRect.height > viewportBottom) {
      top = viewportBottom - tooltipRect.height;
    }
    // fix left
    if (left < viewportLeft) {
      left = viewportLeft;
    } else if (left + tooltipRect.width > viewportRight) {
      left = viewportRight - tooltipRect.width;
    }
    // fix for popover pointer
    if (placement === PLACEMENTS$1.BOTTOM) {
      top -= popoverFix;
    } else if (placement === PLACEMENTS$1.LEFT) {
      left += popoverFix;
    } else if (placement === PLACEMENTS$1.RIGHT) {
      left -= popoverFix;
    } else {
      top += popoverFix;
    }
  }
  // set position finally
  tooltip.style.top = top + "px";
  tooltip.style.left = left + "px";
}

function hasScrollbar(el) {
  var SCROLL = 'scroll';
  var hasVScroll = el.scrollHeight > el.clientHeight;
  var style = getComputedStyle(el);
  return hasVScroll || style.overflow === SCROLL || style.overflowY === SCROLL
}

function toggleBodyOverflow(enable) {
  var MODAL_OPEN = 'modal-open';
  var FIXED_CONTENT = '.navbar-fixed-top, .navbar-fixed-bottom';
  var body = document.body;
  if (enable) {
    removeClass(body, MODAL_OPEN);
    body.style.paddingRight = null;
    nodeListToArray(document.querySelectorAll(FIXED_CONTENT)).forEach(
      function (node) {
        node.style.paddingRight = null;
      }
    );
  } else {
    var browsersWithFloatingScrollbar = isIE10() || isIE11();
    var documentHasScrollbar =
      hasScrollbar(document.documentElement) || hasScrollbar(document.body);
    if (documentHasScrollbar && !browsersWithFloatingScrollbar) {
      var scrollbarWidth = getScrollbarWidth();
      body.style.paddingRight = scrollbarWidth + "px";
      nodeListToArray(document.querySelectorAll(FIXED_CONTENT)).forEach(
        function (node) {
          node.style.paddingRight = scrollbarWidth + "px";
        }
      );
    }
    addClass(body, MODAL_OPEN);
  }
}

function getClosest(el, selector) {
  ensureElementMatchesFunction();
  var parent;
  var _el = el;
  while (_el) {
    parent = _el.parentElement;
    if (parent && parent.matches(selector)) {
      return parent
    }
    _el = parent;
  }
  return null
}

function getParents(el, selector, until) {
  if ( until === void 0 ) until = null;

  ensureElementMatchesFunction();
  var parents = [];
  var parent = el.parentElement;
  while (parent) {
    if (parent.matches(selector)) {
      parents.push(parent);
    } else if (until && (until === parent || parent.matches(until))) {
      break
    }
    parent = parent.parentElement;
  }
  return parents
}

function focus(el) {
  if (!isElement(el)) {
    return
  }
  el.getAttribute('tabindex') ? null : el.setAttribute('tabindex', '-1');
  el.focus();
}

var MODAL_BACKDROP = 'modal-backdrop';

function getOpenModals() {
  return document.querySelectorAll(("." + MODAL_BACKDROP))
}

function getOpenModalNum() {
  return getOpenModals().length
}

function getElementBySelectorOrRef(q) {
  if (isString(q)) {
    // is selector
    return document.querySelector(q)
  } else if (isElement(q)) {
    // is element
    return q
  } else if (isElement(q.$el)) {
    // is component
    return q.$el
  } else {
    return null
  }
}

var COLLAPSE = 'collapse';
var IN$1 = 'in';
var COLLAPSING = 'collapsing';

var Collapse = {
  render: function render() {
    return h(this.tag, {}, this.$slots.default && this.$slots.default())
  },
  props: {
    tag: {
      type: String,
      default: 'div',
    },
    modelValue: {
      type: Boolean,
      default: false,
    },
    transition: {
      type: Number,
      default: 350,
    },
  },
  data: function data() {
    return {
      timeoutId: 0,
    }
  },
  watch: {
    modelValue: function modelValue(show) {
      this.toggle(show);
    },
  },
  mounted: function mounted() {
    var el = this.$el;
    addClass(el, COLLAPSE);
    if (this.modelValue) {
      addClass(el, IN$1);
    }
  },
  methods: {
    toggle: function toggle(show) {
      var this$1$1 = this;

      clearTimeout(this.timeoutId);
      var el = this.$el;
      if (show) {
        this.$emit('show');
        removeClass(el, COLLAPSE);
        el.style.height = 'auto';
        var height = window.getComputedStyle(el).height;
        el.style.height = null;
        addClass(el, COLLAPSING);
        el.offsetHeight; // force repaint
        el.style.height = height;
        this.timeoutId = setTimeout(function () {
          removeClass(el, COLLAPSING);
          addClass(el, COLLAPSE);
          addClass(el, IN$1);
          el.style.height = null;
          this$1$1.timeoutId = 0;
          this$1$1.$emit('shown');
        }, this.transition);
      } else {
        this.$emit('hide');
        el.style.height = window.getComputedStyle(el).height;
        removeClass(el, IN$1);
        removeClass(el, COLLAPSE);
        el.offsetHeight;
        el.style.height = null;
        addClass(el, COLLAPSING);
        this.timeoutId = setTimeout(function () {
          addClass(el, COLLAPSE);
          removeClass(el, COLLAPSING);
          el.style.height = null;
          this$1$1.timeoutId = 0;
          this$1$1.$emit('hidden');
        }, this.transition);
      }
    },
  },
};

var DEFAULT_TAG = 'div';

var script$s = {
  props: {
    tag: {
      type: String,
      default: DEFAULT_TAG,
    },
    appendToBody: {
      type: Boolean,
      default: false,
    },
    modelValue: Boolean,
    dropup: {
      type: Boolean,
      default: false,
    },
    menuRight: {
      type: Boolean,
      default: false,
    },
    disabled: {
      type: Boolean,
      default: false,
    },
    notCloseElements: { type: Array, default: function () { return []; } },
    positionElement: { type: null, default: undefined },
  },
  emits: ['update:modelValue'],
  data: function data() {
    return {
      show: false,
      triggerEl: undefined,
    }
  },
  watch: {
    modelValue: function modelValue(v) {
      this.toggle(v);
    },
  },
  mounted: function mounted() {
    this.initTrigger();
    if (this.triggerEl) {
      on(this.triggerEl, EVENTS.CLICK, this.toggle);
      on(this.triggerEl, EVENTS.KEY_DOWN, this.onKeyPress);
    }
    on(this.$refs.dropdown, EVENTS.KEY_DOWN, this.onKeyPress);
    on(window, EVENTS.CLICK, this.windowClicked);
    on(window, EVENTS.TOUCH_END, this.windowClicked);
    if (this.modelValue) {
      this.toggle(true);
    }
  },
  beforeUnmount: function beforeUnmount() {
    this.removeDropdownFromBody();
    if (this.triggerEl) {
      off(this.triggerEl, EVENTS.CLICK, this.toggle);
      off(this.triggerEl, EVENTS.KEY_DOWN, this.onKeyPress);
    }
    off(this.$refs.dropdown, EVENTS.KEY_DOWN, this.onKeyPress);
    off(window, EVENTS.CLICK, this.windowClicked);
    off(window, EVENTS.TOUCH_END, this.windowClicked);
  },
  methods: {
    getFocusItem: function getFocusItem() {
      var dropdownEl = this.$refs.dropdown;
      return dropdownEl.querySelector('li > a:focus')
    },
    onKeyPress: function onKeyPress(event) {
      if (this.show) {
        var dropdownEl = this.$refs.dropdown;
        var keyCode = event.keyCode;
        if (keyCode === 27) {
          // esc
          this.toggle(false);
          this.triggerEl && this.triggerEl.focus();
        } else if (keyCode === 13) {
          // enter
          var currentFocus = this.getFocusItem();
          currentFocus && currentFocus.click();
        } else if (keyCode === 38 || keyCode === 40) {
          // up || down
          event.preventDefault();
          event.stopPropagation();
          var currentFocus$1 = this.getFocusItem();
          var items = dropdownEl.querySelectorAll('li:not(.disabled) > a');
          if (!currentFocus$1) {
            focus(items[0]);
          } else {
            for (var i = 0; i < items.length; i++) {
              if (currentFocus$1 === items[i]) {
                if (keyCode === 38 && i < items.length > 0) {
                  focus(items[i - 1]);
                } else if (keyCode === 40 && i < items.length - 1) {
                  focus(items[i + 1]);
                }
                break
              }
            }
          }
        }
      }
    },
    initTrigger: function initTrigger() {
      var trigger =
        this.$el.querySelector('[data-role="trigger"]') ||
        this.$el.querySelector('.dropdown-toggle') ||
        this.$el.firstChild;
      this.triggerEl =
        trigger && trigger !== this.$refs.dropdown ? trigger : null;
    },
    toggle: function toggle(show) {
      if (this.disabled) {
        return
      }
      if (isBoolean(show)) {
        this.show = show;
      } else {
        this.show = !this.show;
      }
      if (this.appendToBody) {
        this.show ? this.appendDropdownToBody() : this.removeDropdownFromBody();
      }
      this.$emit('update:modelValue', this.show);
    },
    windowClicked: function windowClicked(event) {
      var target = event.target;
      if (this.show && target) {
        var targetInNotCloseElements = false;
        if (this.notCloseElements) {
          for (var i = 0, l = this.notCloseElements.length; i < l; i++) {
            var isTargetInElement = this.notCloseElements[i].contains(target);
            var shouldBreak = isTargetInElement;
            /* istanbul ignore else */
            if (this.appendToBody) {
              var isTargetInDropdown = this.$refs.dropdown.contains(target);
              var isElInElements =
                this.notCloseElements.indexOf(this.$el) >= 0;
              shouldBreak =
                isTargetInElement || (isTargetInDropdown && isElInElements);
            }
            if (shouldBreak) {
              targetInNotCloseElements = true;
              break
            }
          }
        }
        var targetInDropdownBody = this.$refs.dropdown.contains(target);
        var targetInTrigger =
          this.$el.contains(target) && !targetInDropdownBody;
        // normally, a dropdown select event is handled by @click that trigger after @touchend
        // then @touchend event have to be ignore in this case
        var targetInDropdownAndIsTouchEvent =
          targetInDropdownBody && event.type === 'touchend';
        if (
          !targetInTrigger &&
          !targetInNotCloseElements &&
          !targetInDropdownAndIsTouchEvent
        ) {
          this.toggle(false);
        }
      }
    },
    appendDropdownToBody: function appendDropdownToBody() {
      try {
        var el = this.$refs.dropdown;
        el.style.display = 'block';
        document.body.appendChild(el);
        var positionElement = this.positionElement || this.$el;
        setDropdownPosition(el, positionElement, this);
      } catch (e) {
        // Silent
      }
    },
    removeDropdownFromBody: function removeDropdownFromBody() {
      try {
        var el = this.$refs.dropdown;
        el.removeAttribute('style');
        this.$el.appendChild(el);
      } catch (e) {
        // Silent
      }
    },
  },
  render: function render() {
    return h(
      this.tag,
      {
        class: {
          'btn-group': this.tag === DEFAULT_TAG,
          dropdown: !this.dropup,
          dropup: this.dropup,
          open: this.show,
        },
      },
      [
        this.$slots.default && this.$slots.default(),
        h(
          'ul',
          {
            class: {
              'dropdown-menu': true,
              'dropdown-menu-right': this.menuRight,
            },
            ref: 'dropdown',
          },
          [this.$slots.dropdown && this.$slots.dropdown()]
        ) ]
    )
  },
};

script$s.__file = "src/components/dropdown/Dropdown.vue";

var defaultLang = {
  uiv: {
    datePicker: {
      clear: 'Clear',
      today: 'Today',
      month: 'Month',
      month1: 'January',
      month2: 'February',
      month3: 'March',
      month4: 'April',
      month5: 'May',
      month6: 'June',
      month7: 'July',
      month8: 'August',
      month9: 'September',
      month10: 'October',
      month11: 'November',
      month12: 'December',
      year: 'Year',
      week1: 'Mon',
      week2: 'Tue',
      week3: 'Wed',
      week4: 'Thu',
      week5: 'Fri',
      week6: 'Sat',
      week7: 'Sun',
    },
    timePicker: {
      am: 'AM',
      pm: 'PM',
    },
    modal: {
      cancel: 'Cancel',
      ok: 'OK',
    },
    multiSelect: {
      placeholder: 'Select...',
      filterPlaceholder: 'Search...',
    },
  },
};

var lang = defaultLang;

var i18nHandler = function () {
  if ('$t' in this) {
    return this.$t.apply(this, arguments)
  }
  return null
};

var t = function (path, options) {
  options = options || {};
  var value;
  try {
    value = i18nHandler.apply(this, arguments);
    /* istanbul ignore next */
    if (isExist(value) && !options.$$locale) {
      return value
    }
  } catch (e) {
    // ignore
  }
  var array = path.split('.');
  var current = options.$$locale || lang;

  for (var i = 0, j = array.length; i < j; i++) {
    var property = array[i];
    value = current[property];
    if (i === j - 1) { return value }
    if (!value) { return '' }
    current = value;
  }
  /* istanbul ignore next */
  return ''
};

var use = function (l) {
  lang = l || lang;
};

var i18n = function (fn) {
  i18nHandler = fn || i18nHandler;
};

var locale = { use: use, t: t, i18n: i18n };

var Local = {
  methods: {
    t: function t$1() {
      var arguments$1 = arguments;

      var args = [];
      for (var i = 0; i < arguments.length; ++i) {
        args.push(arguments$1[i]);
      }
      args[1] = assign({}, { $$locale: this.locale }, args[1]);
      return t.apply(this, args)
    },
  },
  props: {
    locale: Object,
  },
};

var linkMixin = {
  props: {
    // <a> props
    href: String,
    target: String,
    // <router-link> props
    to: null,
    replace: {
      type: Boolean,
      default: false,
    },
    append: {
      type: Boolean,
      default: false,
    },
    exact: {
      type: Boolean,
      default: false,
    },
  },
};

var script$r = {
  props: {
    size: { type: String, default: undefined },
    vertical: {
      type: Boolean,
      default: false,
    },
    justified: {
      type: Boolean,
      default: false,
    },
  },
};

function render$p(_ctx, _cache, $props, $setup, $data, $options) {
  var obj;

  return (openBlock(), createElementBlock("div", {
    class: normalizeClass(( obj = {
      'btn-group': !$props.vertical,
      'btn-group-vertical': $props.vertical,
      'btn-group-justified': $props.justified
    }, obj[("btn-group-" + ($props.size))] = $props.size, obj )),
    role: "group",
    "data-toggle": "buttons"
  }, [
    renderSlot(_ctx.$slots, "default")
  ], 2 /* CLASS */))
}

script$r.render = render$p;
script$r.__file = "src/components/button/BtnGroup.vue";

var INPUT_TYPE_CHECKBOX = 'checkbox';
var INPUT_TYPE_RADIO = 'radio';

var script$q = {
  components: { BtnGroup: script$r },
  mixins: [linkMixin],
  props: {
    justified: {
      type: Boolean,
      default: false,
    },
    type: {
      type: String,
      default: 'default',
    },
    nativeType: {
      type: String,
      default: 'button',
    },
    size: {
      type: String,
      default: undefined,
    },
    block: {
      type: Boolean,
      default: false,
    },
    active: {
      type: Boolean,
      default: false,
    },
    disabled: {
      type: Boolean,
      default: false,
    },
    // <input> props
    modelValue: {
      type: null,
      default: null,
    },
    inputValue: {
      type: null,
      default: null,
    },
    inputType: {
      type: String,
      validator: function validator(value) {
        return value === INPUT_TYPE_CHECKBOX || value === INPUT_TYPE_RADIO
      },
      default: undefined,
    },
  },
  emits: ['update:modelValue'],
  computed: {
    isInputActive: function isInputActive() {
      return this.inputType === INPUT_TYPE_CHECKBOX
        ? this.modelValue.indexOf(this.inputValue) >= 0
        : this.modelValue === this.inputValue
    },
    classes: function classes() {
      var obj;

      return ( obj = {
        btn: true,
        active: this.inputType ? this.isInputActive : this.active,
        disabled: this.disabled,
        'btn-block': this.block
      }, obj[("btn-" + (this.type))] = Boolean(this.type), obj[("btn-" + (this.size))] = Boolean(this.size), obj )
    },
  },
  methods: {
    onClick: function onClick(e) {
      if (this.disabled && e instanceof Event) {
        e.preventDefault();
        e.stopPropagation();
      }
    },
    onInputChange: function onInputChange() {
      if (this.inputType === INPUT_TYPE_CHECKBOX) {
        var valueCopied = this.modelValue.slice();
        if (this.isInputActive) {
          valueCopied.splice(valueCopied.indexOf(this.inputValue), 1);
        } else {
          valueCopied.push(this.inputValue);
        }
        this.$emit('update:modelValue', valueCopied);
      } else {
        this.$emit('update:modelValue', this.inputValue);
      }
    },
  },
};

var _hoisted_1$k = ["href", "target"];
var _hoisted_2$e = ["type", "checked", "disabled"];
var _hoisted_3$a = ["type", "disabled"];
var _hoisted_4$9 = ["type", "disabled"];

function render$o(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_router_link = resolveComponent("router-link");
  var _component_BtnGroup = resolveComponent("BtnGroup");

  return (_ctx.href)
    ? (openBlock(), createElementBlock("a", {
        key: 0,
        href: _ctx.href,
        target: _ctx.target,
        role: "button",
        class: normalizeClass($options.classes),
        onClick: _cache[0] || (_cache[0] = function () {
          var args = [], len = arguments.length;
          while ( len-- ) args[ len ] = arguments[ len ];

          return ($options.onClick && $options.onClick.apply($options, args));
  })
      }, [
        renderSlot(_ctx.$slots, "default")
      ], 10 /* CLASS, PROPS */, _hoisted_1$k))
    : (_ctx.to)
      ? (openBlock(), createBlock(_component_router_link, {
          key: 1,
          to: _ctx.to,
          class: normalizeClass($options.classes),
          event: $props.disabled ? '' : 'click',
          replace: _ctx.replace,
          append: _ctx.append,
          exact: _ctx.exact,
          role: "button",
          onClick: $options.onClick
        }, {
          default: withCtx(function () { return [
            renderSlot(_ctx.$slots, "default")
          ]; }),
          _: 3 /* FORWARDED */
        }, 8 /* PROPS */, ["to", "class", "event", "replace", "append", "exact", "onClick"]))
      : ($props.inputType)
        ? (openBlock(), createElementBlock("label", {
            key: 2,
            class: normalizeClass($options.classes),
            onClick: _cache[3] || (_cache[3] = function () {
              var args = [], len = arguments.length;
              while ( len-- ) args[ len ] = arguments[ len ];

              return ($options.onClick && $options.onClick.apply($options, args));
  })
          }, [
            createElementVNode("input", {
              autocomplete: "off",
              type: $props.inputType,
              checked: $options.isInputActive,
              disabled: $props.disabled,
              onInput: _cache[1] || (_cache[1] = withModifiers(function () {}, ["stop"])),
              onChange: _cache[2] || (_cache[2] = function () {
                var args = [], len = arguments.length;
                while ( len-- ) args[ len ] = arguments[ len ];

                return ($options.onInputChange && $options.onInputChange.apply($options, args));
  })
            }, null, 40 /* PROPS, HYDRATE_EVENTS */, _hoisted_2$e),
            renderSlot(_ctx.$slots, "default")
          ], 2 /* CLASS */))
        : ($props.justified)
          ? (openBlock(), createBlock(_component_BtnGroup, { key: 3 }, {
              default: withCtx(function () { return [
                createElementVNode("button", {
                  class: normalizeClass($options.classes),
                  type: $props.nativeType,
                  disabled: $props.disabled,
                  onClick: _cache[4] || (_cache[4] = function () {
                    var args = [], len = arguments.length;
                    while ( len-- ) args[ len ] = arguments[ len ];

                    return ($options.onClick && $options.onClick.apply($options, args));
                })
                }, [
                  renderSlot(_ctx.$slots, "default")
                ], 10 /* CLASS, PROPS */, _hoisted_3$a)
              ]; }),
              _: 3 /* FORWARDED */
            }))
          : (openBlock(), createElementBlock("button", {
              key: 4,
              class: normalizeClass($options.classes),
              type: $props.nativeType,
              disabled: $props.disabled,
              onClick: _cache[5] || (_cache[5] = function () {
                var args = [], len = arguments.length;
                while ( len-- ) args[ len ] = arguments[ len ];

                return ($options.onClick && $options.onClick.apply($options, args));
  })
            }, [
              renderSlot(_ctx.$slots, "default")
            ], 10 /* CLASS, PROPS */, _hoisted_4$9))
}

script$q.render = render$o;
script$q.__file = "src/components/button/Btn.vue";

var IN = 'in';

var script$p = {
  components: { Btn: script$q },
  mixins: [Local],
  props: {
    modelValue: {
      type: Boolean,
      default: false,
    },
    title: { type: String, default: undefined },
    size: { type: String, default: undefined },
    backdrop: {
      type: Boolean,
      default: true,
    },
    footer: {
      type: Boolean,
      default: true,
    },
    header: {
      type: Boolean,
      default: true,
    },
    cancelText: { type: String, default: undefined },
    cancelType: {
      type: String,
      default: 'default',
    },
    okText: { type: String, default: undefined },
    okType: {
      type: String,
      default: 'primary',
    },
    dismissBtn: {
      type: Boolean,
      default: true,
    },
    transition: {
      type: Number,
      default: 150,
    },
    autoFocus: {
      type: Boolean,
      default: false,
    },
    keyboard: {
      type: Boolean,
      default: true,
    },
    beforeClose: { type: Function, default: undefined },
    zOffset: {
      type: Number,
      default: 20,
    },
    appendToBody: {
      type: Boolean,
      default: false,
    },
    displayStyle: {
      type: String,
      default: 'block',
    },
  },
  emits: ['update:modelValue', 'show', 'hide'],
  data: function data() {
    return {
      msg: '',
    }
  },
  computed: {
    modalSizeClass: function modalSizeClass() {
      var obj;

      return ( obj = {}, obj[("modal-" + (this.size))] = Boolean(this.size), obj )
    },
  },
  watch: {
    modelValue: function modelValue(v) {
      this.$toggle(v);
    },
  },
  mounted: function mounted() {
    removeFromDom(this.$refs.backdrop);
    on(window, EVENTS.MOUSE_DOWN, this.suppressBackgroundClose);
    on(window, EVENTS.KEY_UP, this.onKeyPress);
    if (this.modelValue) {
      this.$toggle(true);
    }
  },
  beforeUnmount: function beforeUnmount() {
    clearTimeout(this.timeoutId);
    removeFromDom(this.$refs.backdrop);
    removeFromDom(this.$el);
    if (getOpenModalNum() === 0) {
      toggleBodyOverflow(true);
    }
    off(window, EVENTS.MOUSE_DOWN, this.suppressBackgroundClose);
    off(window, EVENTS.MOUSE_UP, this.unsuppressBackgroundClose);
    off(window, EVENTS.KEY_UP, this.onKeyPress);
  },
  methods: {
    onKeyPress: function onKeyPress(event) {
      if (this.keyboard && this.modelValue && event.keyCode === 27) {
        var thisModal = this.$refs.backdrop;
        var thisZIndex = thisModal.style.zIndex;
        thisZIndex =
          thisZIndex && thisZIndex !== 'auto' ? parseInt(thisZIndex) : 0;
        // Find out if this modal is the top most one.
        var modals = getOpenModals();
        var modalsLength = modals.length;
        for (var i = 0; i < modalsLength; i++) {
          if (modals[i] !== thisModal) {
            var zIndex = modals[i].style.zIndex;
            zIndex = zIndex && zIndex !== 'auto' ? parseInt(zIndex) : 0;
            // if any existing modal has higher zIndex, ignore
            if (zIndex > thisZIndex) {
              return
            }
          }
        }
        this.toggle(false);
      }
    },
    toggle: function toggle(show, msg) {
      var this$1$1 = this;

      var shouldClose = true;
      if (isFunction(this.beforeClose)) {
        shouldClose = this.beforeClose(msg);
      }

      if (isPromiseSupported()) {
        // Skip the hiding when beforeClose returning falsely value or returned Promise resolves to falsely value
        // Use Promise.resolve to accept both Boolean values and Promises
        Promise.resolve(shouldClose).then(function (shouldClose) {
          // Skip the hiding while show===false
          if (!show && shouldClose) {
            this$1$1.msg = msg;
            this$1$1.$emit('update:modelValue', show);
          }
        });
      } else {
        // Fallback to old version if promise is not supported
        // skip the hiding while show===false & beforeClose returning falsely value
        if (!show && !shouldClose) {
          return
        }

        this.msg = msg;
        this.$emit('update:modelValue', show);
      }
    },
    $toggle: function $toggle(show) {
      var this$1$1 = this;

      var modal = this.$el;
      var backdrop = this.$refs.backdrop;
      clearTimeout(this.timeoutId);
      if (show) {
        // If two modals share the same v-if condition the calculated z-index is incorrect,
        // resulting in popover misbehaviour.
        // solved by adding a nextTick.
        // https://github.com/uiv-lib/uiv/issues/342
        this.$nextTick(function () {
          var alreadyOpenModalNum = getOpenModalNum();
          document.body.appendChild(backdrop);
          if (this$1$1.appendToBody) {
            document.body.appendChild(modal);
          }
          modal.style.display = this$1$1.displayStyle;
          modal.scrollTop = 0;
          backdrop.offsetHeight; // force repaint
          toggleBodyOverflow(false);
          addClass(backdrop, IN);
          addClass(modal, IN);
          // fix z-index for nested modals
          // no need to calculate if no modal is already open
          if (alreadyOpenModalNum > 0) {
            var modalBaseZ = parseInt(getComputedStyle(modal).zIndex) || 1050; // 1050 is default modal z-Index
            var backdropBaseZ =
              parseInt(getComputedStyle(backdrop).zIndex) || 1040; // 1040 is default backdrop z-Index
            var offset = alreadyOpenModalNum * this$1$1.zOffset;
            modal.style.zIndex = "" + (modalBaseZ + offset);
            backdrop.style.zIndex = "" + (backdropBaseZ + offset);
          }
          // z-index fix end
          this$1$1.timeoutId = setTimeout(function () {
            if (this$1$1.autoFocus) {
              var btn = this$1$1.$el.querySelector('[data-action="auto-focus"]');
              if (btn) {
                btn.focus();
              }
            }
            this$1$1.$emit('show');
            this$1$1.timeoutId = 0;
          }, this$1$1.transition);
        });
      } else {
        removeClass(backdrop, IN);
        removeClass(modal, IN);
        this.timeoutId = setTimeout(function () {
          modal.style.display = 'none';
          removeFromDom(backdrop);
          if (this$1$1.appendToBody) {
            removeFromDom(modal);
          }
          if (getOpenModalNum() === 0) {
            toggleBodyOverflow(true);
          }
          this$1$1.$emit('hide', this$1$1.msg || 'dismiss');
          this$1$1.msg = '';
          this$1$1.timeoutId = 0;
          // restore z-index for nested modals
          modal.style.zIndex = '';
          backdrop.style.zIndex = '';
          // z-index fix end
        }, this.transition);
      }
    },
    suppressBackgroundClose: function suppressBackgroundClose(event) {
      if (event && event.target === this.$el) {
        return
      }
      this.isCloseSuppressed = true;
      on(window, 'mouseup', this.unsuppressBackgroundClose);
    },
    unsuppressBackgroundClose: function unsuppressBackgroundClose() {
      var this$1$1 = this;

      if (this.isCloseSuppressed) {
        off(window, 'mouseup', this.unsuppressBackgroundClose);
        setTimeout(function () {
          this$1$1.isCloseSuppressed = false;
        }, 1);
      }
    },
    backdropClicked: function backdropClicked(event) {
      if (this.backdrop && !this.isCloseSuppressed) {
        this.toggle(false);
      }
    },
  },
};

var _hoisted_1$j = { class: "modal-content" };
var _hoisted_2$d = {
  key: 0,
  class: "modal-header"
};
var _hoisted_3$9 = /*#__PURE__*/createElementVNode("span", { "aria-hidden": "true" }, "×", -1 /* HOISTED */);
var _hoisted_4$8 = { class: "modal-title" };
var _hoisted_5$7 = { class: "modal-body" };
var _hoisted_6$6 = {
  key: 1,
  class: "modal-footer"
};

function render$n(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_btn = resolveComponent("btn");

  return (openBlock(), createElementBlock("div", {
    tabindex: "-1",
    role: "dialog",
    class: normalizeClass(["modal", { fade: $props.transition > 0 }]),
    onClick: _cache[3] || (_cache[3] = withModifiers(function () {
      var args = [], len = arguments.length;
      while ( len-- ) args[ len ] = arguments[ len ];

      return ($options.backdropClicked && $options.backdropClicked.apply($options, args));
  }, ["self"]))
  }, [
    createElementVNode("div", {
      ref: "dialog",
      class: normalizeClass(["modal-dialog", $options.modalSizeClass]),
      role: "document"
    }, [
      createElementVNode("div", _hoisted_1$j, [
        ($props.header)
          ? (openBlock(), createElementBlock("div", _hoisted_2$d, [
              renderSlot(_ctx.$slots, "header", {}, function () { return [
                ($props.dismissBtn)
                  ? (openBlock(), createElementBlock("button", {
                      key: 0,
                      type: "button",
                      class: "close",
                      "aria-label": "Close",
                      style: {"position":"relative","z-index":"1060"},
                      onClick: _cache[0] || (_cache[0] = function ($event) { return ($options.toggle(false)); })
                    }, [
                      createCommentVNode(" 1060 is bigger than dialog z-index 1050 because it got cover by title sometimes "),
                      _hoisted_3$9
                    ]))
                  : createCommentVNode("v-if", true),
                createElementVNode("h4", _hoisted_4$8, [
                  renderSlot(_ctx.$slots, "title", {}, function () { return [
                    createTextVNode(toDisplayString($props.title), 1 /* TEXT */)
                  ]; })
                ])
              ]; })
            ]))
          : createCommentVNode("v-if", true),
        createElementVNode("div", _hoisted_5$7, [
          renderSlot(_ctx.$slots, "default")
        ]),
        ($props.footer)
          ? (openBlock(), createElementBlock("div", _hoisted_6$6, [
              renderSlot(_ctx.$slots, "footer", {}, function () { return [
                createVNode(_component_btn, {
                  type: $props.cancelType,
                  onClick: _cache[1] || (_cache[1] = function ($event) { return ($options.toggle(false, 'cancel')); })
                }, {
                  default: withCtx(function () { return [
                    createElementVNode("span", null, toDisplayString($props.cancelText || _ctx.t('uiv.modal.cancel')), 1 /* TEXT */)
                  ]; }),
                  _: 1 /* STABLE */
                }, 8 /* PROPS */, ["type"]),
                createVNode(_component_btn, {
                  type: $props.okType,
                  "data-action": "auto-focus",
                  onClick: _cache[2] || (_cache[2] = function ($event) { return ($options.toggle(false, 'ok')); })
                }, {
                  default: withCtx(function () { return [
                    createElementVNode("span", null, toDisplayString($props.okText || _ctx.t('uiv.modal.ok')), 1 /* TEXT */)
                  ]; }),
                  _: 1 /* STABLE */
                }, 8 /* PROPS */, ["type"])
              ]; })
            ]))
          : createCommentVNode("v-if", true)
      ])
    ], 2 /* CLASS */),
    createElementVNode("div", {
      ref: "backdrop",
      class: normalizeClass(["modal-backdrop", { fade: $props.transition > 0 }])
    }, null, 2 /* CLASS */)
  ], 2 /* CLASS */))
}

script$p.render = render$n;
script$p.__file = "src/components/modal/Modal.vue";

var ACTIVE_CLASS = 'active';
var IN_CLASS$1 = 'in';

var id = 0;

var script$o = {
  props: {
    title: {
      type: String,
      default: 'Tab Title',
    },
    disabled: {
      type: Boolean,
      default: false,
    },
    tabClasses: {
      type: Object,
      default: function () {
        return {}
      },
    },
    group: { type: String, default: undefined },
    pullRight: {
      type: Boolean,
      default: false,
    },
    hidden: {
      type: Boolean,
      default: false,
    },
  },
  data: function data() {
    return {
      active: null,
      transition: 150,
      uid: ("tab_" + (++id)),
      isMounted: false,
    }
  },
  watch: {
    active: function active(active$1) {
      var this$1$1 = this;

      if (active$1) {
        setTimeout(function () {
          addClass(this$1$1.$el, ACTIVE_CLASS);
          this$1$1.$el.offsetHeight;
          addClass(this$1$1.$el, IN_CLASS$1);
          try {
            this$1$1.$parent.$emit('changed', this$1$1.$parent.activeIndex);
          } catch (e) {
            throw new Error('<tab> parent must be <tabs>.')
          }
        }, this.transition);
      } else {
        removeClass(this.$el, IN_CLASS$1);
        setTimeout(function () {
          removeClass(this$1$1.$el, ACTIVE_CLASS);
        }, this.transition);
      }
    },
  },
  created: function created() {
    try {
      this.$parent.tabs.push(this);
    } catch (e) {
      throw new Error('<tab> parent must be <tabs>.')
    }
  },
  mounted: function mounted() {
    this.isMounted = true;
  },
  beforeUnmount: function beforeUnmount() {
    var tabs = this.$parent && this.$parent.tabs;
    spliceIfExist(tabs, this);
  },
  methods: {
    show: function show() {
      var this$1$1 = this;

      this.$nextTick(function () {
        addClass(this$1$1.$el, ACTIVE_CLASS);
        addClass(this$1$1.$el, IN_CLASS$1);
      });
    },
  },
};

function render$m(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("div", {
    class: normalizeClass(["tab-pane", { fade: $data.transition > 0 }]),
    role: "tabpanel"
  }, [
    renderSlot(_ctx.$slots, "default"),
    ($data.isMounted && _ctx.$slots.title)
      ? (openBlock(), createBlock(Teleport, {
          key: 0,
          to: '#' + $data.uid.toString()
        }, [
          renderSlot(_ctx.$slots, "title")
        ], 8 /* PROPS */, ["to"]))
      : createCommentVNode("v-if", true)
  ], 2 /* CLASS */))
}

script$o.render = render$m;
script$o.__file = "src/components/tabs/Tab.vue";

var script$n = {
  components: { Dropdown: script$s },
  props: {
    modelValue: {
      type: Number,
      validator: function (v) { return v >= 0; },
      default: undefined,
    },
    transition: {
      type: Number,
      default: 150,
    },
    justified: Boolean,
    pills: Boolean,
    stacked: Boolean,
    customNavClass: { type: null, default: undefined },
    customContentClass: { type: null, default: undefined },
    beforeChange: { type: Function, default: undefined },
  },
  emits: ['update:modelValue', 'change', 'changed'],
  data: function data() {
    return {
      tabs: [],
      activeIndex: 0, // Make v-model not required
    }
  },
  computed: {
    navClasses: function navClasses() {
      var obj;

      var tabClasses = {
        nav: true,
        'nav-justified': this.justified,
        'nav-tabs': !this.pills,
        'nav-pills': this.pills,
        'nav-stacked': this.stacked && this.pills,
      };
      var customNavClass = this.customNavClass;
      if (isExist(customNavClass)) {
        if (isString(customNavClass)) {
          return assign({}, tabClasses, ( obj = {}, obj[customNavClass] = true, obj ))
        } else {
          return assign({}, tabClasses, customNavClass)
        }
      } else {
        return tabClasses
      }
    },
    contentClasses: function contentClasses() {
      var obj;

      var contentClasses = {
        'tab-content': true,
      };
      var customContentClass = this.customContentClass;
      if (isExist(customContentClass)) {
        if (isString(customContentClass)) {
          return assign({}, contentClasses, ( obj = {}, obj[customContentClass] = true, obj ))
        } else {
          return assign({}, contentClasses, customContentClass)
        }
      } else {
        return contentClasses
      }
    },
    groupedTabs: function groupedTabs() {
      var tabs = [];
      var hash = {};
      this.tabs.forEach(function (tab) {
        if (tab.group) {
          if (hasOwnProperty(hash, tab.group)) {
            tabs[hash[tab.group]].tabs.push(tab);
          } else {
            tabs.push({
              tabs: [tab],
              group: tab.group,
            });
            hash[tab.group] = tabs.length - 1;
          }
          if (tab.active) {
            tabs[hash[tab.group]].active = true;
          }
          if (tab.pullRight) {
            tabs[hash[tab.group]].pullRight = true;
          }
        } else {
          tabs.push(tab);
        }
      });
      tabs = tabs.map(function (tab) {
        if (Array.isArray(tab.tabs)) {
          tab.hidden =
            tab.tabs.filter(function (v) { return v.hidden; }).length === tab.tabs.length;
        }
        return tab
      });
      return tabs
    },
  },
  watch: {
    modelValue: function modelValue(value) {
      if (isNumber(value)) {
        this.activeIndex = value;
        this.selectCurrent();
      }
    },
    tabs: function tabs(tabs$1) {
      var this$1$1 = this;

      tabs$1.forEach(function (tab, index) {
        tab.transition = this$1$1.transition;
        if (index === this$1$1.activeIndex) {
          tab.show();
        }
      });
      this.selectCurrent();
    },
  },
  mounted: function mounted() {
    this.selectCurrent();
  },
  methods: {
    getTabClasses: function getTabClasses(tab, isSubTab) {
      if ( isSubTab === void 0 ) isSubTab = false;

      var defaultClasses = {
        active: tab.active,
        disabled: tab.disabled,
        'pull-right': tab.pullRight && !isSubTab,
      };

      // return with new classes added to tab
      return assign(defaultClasses, tab.tabClasses)
    },
    selectCurrent: function selectCurrent() {
      var this$1$1 = this;

      var found = false;
      this.tabs.forEach(function (tab, index) {
        if (index === this$1$1.activeIndex) {
          found = !tab.active;
          tab.active = true;
        } else {
          tab.active = false;
        }
      });
      if (found) {
        this.$emit('change', this.activeIndex);
      }
    },
    selectValidate: function selectValidate(index) {
      var this$1$1 = this;

      if (isFunction(this.beforeChange)) {
        this.beforeChange(this.activeIndex, index, function (result) {
          if (!isExist(result)) {
            this$1$1.$select(index);
          }
        });
      } else {
        this.$select(index);
      }
    },
    select: function select(index) {
      if (!this.tabs[index].disabled && index !== this.activeIndex) {
        this.selectValidate(index);
      }
    },
    $select: function $select(index) {
      if (isNumber(this.modelValue)) {
        this.$emit('update:modelValue', index);
      } else {
        this.activeIndex = index;
        this.selectCurrent();
      }
    },
  },
};

var _hoisted_1$i = /*#__PURE__*/createElementVNode("span", { class: "caret" }, null, -1 /* HOISTED */);
var _hoisted_2$c = ["onClick"];
var _hoisted_3$8 = ["id", "onClick"];
var _hoisted_4$7 = ["onClick", "textContent"];
var _hoisted_5$6 = {
  key: 0,
  class: "pull-right"
};

function render$l(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_dropdown = resolveComponent("dropdown");

  return (openBlock(), createElementBlock("section", null, [
    createElementVNode("ul", {
      class: normalizeClass($options.navClasses),
      role: "tablist"
    }, [
      (openBlock(true), createElementBlock(Fragment, null, renderList($options.groupedTabs, function (tab, i) {
        return (openBlock(), createElementBlock(Fragment, { key: i }, [
          (tab.tabs)
            ? withDirectives((openBlock(), createBlock(_component_dropdown, {
                key: 0,
                role: "presentation",
                tag: "li",
                class: normalizeClass($options.getTabClasses(tab))
              }, {
                dropdown: withCtx(function () { return [
                  (openBlock(true), createElementBlock(Fragment, null, renderList(tab.tabs, function (subTab, j) {
                    return withDirectives((openBlock(), createElementBlock("li", {
                      key: (i + "_" + j),
                      class: normalizeClass($options.getTabClasses(subTab, true))
                    }, [
                      createElementVNode("a", {
                        href: "#",
                        onClick: withModifiers(function ($event) { return ($options.select($data.tabs.indexOf(subTab))); }, ["prevent"])
                      }, toDisplayString(subTab.title), 9 /* TEXT, PROPS */, _hoisted_2$c)
                    ], 2 /* CLASS */)), [
                      [vShow, !subTab.hidden]
                    ])
                  }), 128 /* KEYED_FRAGMENT */))
                ]; }),
                default: withCtx(function () { return [
                  createElementVNode("a", {
                    class: "dropdown-toggle",
                    role: "tab",
                    href: "#",
                    onClick: _cache[0] || (_cache[0] = withModifiers(function () {}, ["prevent"]))
                  }, [
                    createTextVNode(toDisplayString(tab.group) + " ", 1 /* TEXT */),
                    _hoisted_1$i
                  ])
                ]; }),
                _: 2 /* DYNAMIC */
              }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["class"])), [
                [vShow, !tab.hidden]
              ])
            : withDirectives((openBlock(), createElementBlock("li", {
                key: 1,
                role: "presentation",
                class: normalizeClass($options.getTabClasses(tab))
              }, [
                (tab.$slots.title)
                  ? (openBlock(), createElementBlock("a", {
                      key: 0,
                      id: tab.uid,
                      role: "tab",
                      href: "#",
                      onClick: withModifiers(function ($event) { return ($options.select($data.tabs.indexOf(tab))); }, ["prevent"])
                    }, null, 8 /* PROPS */, _hoisted_3$8))
                  : (openBlock(), createElementBlock("a", {
                      key: 1,
                      role: "tab",
                      href: "#",
                      onClick: withModifiers(function ($event) { return ($options.select($data.tabs.indexOf(tab))); }, ["prevent"]),
                      textContent: toDisplayString(tab.title)
                    }, null, 8 /* PROPS */, _hoisted_4$7))
              ], 2 /* CLASS */)), [
                [vShow, !tab.hidden]
              ])
        ], 64 /* STABLE_FRAGMENT */))
      }), 128 /* KEYED_FRAGMENT */)),
      (!$props.justified && _ctx.$slots['nav-right'])
        ? (openBlock(), createElementBlock("li", _hoisted_5$6, [
            renderSlot(_ctx.$slots, "nav-right")
          ]))
        : createCommentVNode("v-if", true)
    ], 2 /* CLASS */),
    createElementVNode("div", {
      class: normalizeClass($options.contentClasses)
    }, [
      renderSlot(_ctx.$slots, "default")
    ], 2 /* CLASS */)
  ]))
}

script$n.render = render$l;
script$n.__file = "src/components/tabs/Tabs.vue";

function pad(value, num) {
  value = value + '';
  for (var i = num - value.length; i > 0; i--) {
    value = '0' + value;
  }
  return value
}

var monthNames = [
  'January',
  'February',
  'March',
  'April',
  'May',
  'June',
  'July',
  'August',
  'September',
  'October',
  'November',
  'December' ];

/**
 * Get total days number in a month.
 * because we're using 0 as the day so that it returns the last day
 * of the last month, so you have to add 1 to the month number
 * so it returns the correct amount of days.
 * https://stackoverflow.com/questions/1184334/get-number-days-in-a-specified-month-using-javascript
 * @param month 0-based
 * @param year
 * @returns {number}
 */
function daysInMonth(month, year) {
  return new Date(year, month + 1, 0).getDate()
}

function stringify(date, format) {
  try {
    var year = date.getFullYear();
    var month = date.getMonth() + 1;
    var day = date.getDate();
    var monthName = monthNames[month - 1];
    return format
      .replace(/yyyy/g, year)
      .replace(/MMMM/g, monthName)
      .replace(/MMM/g, monthName.substring(0, 3))
      .replace(/MM/g, pad(month, 2))
      .replace(/dd/g, pad(day, 2))
      .replace(/yy/g, year)
      .replace(/M(?!a)/g, month)
      .replace(/d/g, day)
  } catch (e) {
    return ''
  }
}

function convertDateToUTC(date) {
  return new Date(
    date.getUTCFullYear(),
    date.getUTCMonth(),
    date.getUTCDate(),
    date.getUTCHours(),
    date.getUTCMinutes(),
    date.getUTCSeconds()
  )
}

/**
 * https://stackoverflow.com/questions/6117814/get-week-of-year-in-javascript-like-in-php
 * For a given date, get the ISO week number
 * Based on information at:
 *    http://www.merlyn.demon.co.uk/weekcalc.htm#WNR
 *
 * Algorithm is to find nearest thursday, it's year
 * is the year of the week number. Then get weeks
 * between that date and the first day of that year.
 *
 * Note that dates in one year can be weeks of previous
 * or next year, overlap is up to 3 days.
 *
 * e.g. 2014/12/29 is Monday in week  1 of 2015
 *      2012/1/1   is Sunday in week 52 of 2011
 *
 * @param {number} d.year year of date
 * @param {number} d.month month of date
 * @param {number} d.date date of date
 * @returns {number}
 */
function getWeekNumber(d) {
  // Copy date so don't modify original
  var _d = new Date(Date.UTC(d.year, d.month, d.date));
  // Set to nearest Thursday: current date + 4 - current day number
  // Make Sunday's day number 7
  _d.setUTCDate(_d.getUTCDate() + 4 - (_d.getUTCDay() || 7));
  // Get first day of year
  var yearStart = new Date(Date.UTC(_d.getUTCFullYear(), 0, 1));
  // Calculate full weeks to nearest Thursday
  return Math.ceil(((_d - yearStart) / 86400000 + 1) / 7)
}

var script$m = {
  components: { Btn: script$q },
  mixins: [Local],
  props: {
    month: { type: Number, default: undefined },
    year: { type: Number, default: undefined },
    date: { type: Date, default: undefined },
    today: { type: Date, default: undefined },
    limit: { type: Object, default: undefined },
    weekStartsWith: { type: Number, default: undefined },
    iconControlLeft: { type: String, default: undefined },
    iconControlRight: { type: String, default: undefined },
    dateClass: { type: Function, default: undefined },
    yearMonthFormatter: { type: Function, default: undefined },
    weekNumbers: Boolean,
  },
  emits: ['date-change', 'year-change', 'month-change', 'view-change'],
  computed: {
    weekDays: function weekDays() {
      var days = [];
      var firstDay = this.weekStartsWith;
      while (days.length < 7) {
        days.push(firstDay++);
        if (firstDay > 6) {
          firstDay = 0;
        }
      }
      return days
    },
    yearMonthStr: function yearMonthStr() {
      if (this.yearMonthFormatter) {
        return this.yearMonthFormatter(this.year, this.month)
      } else {
        return isExist(this.month)
          ? ((this.year) + " " + (this.t(("uiv.datePicker.month" + (this.month + 1)))))
          : this.year
      }
    },
    monthDayRows: function monthDayRows() {
      var rows = [];
      var firstDay = new Date(this.year, this.month, 1);
      var prevMonthLastDate = new Date(this.year, this.month, 0).getDate();
      var startIndex = firstDay.getDay();
      // console.log(startIndex)
      var daysNum = daysInMonth(this.month, this.year);
      var weekOffset = 0;
      if (this.weekStartsWith > startIndex) {
        weekOffset = 7 - this.weekStartsWith;
      } else {
        weekOffset = 0 - this.weekStartsWith;
      }
      // console.log(prevMonthLastDate, startIndex, daysNum)
      for (var i = 0; i < 6; i++) {
        rows.push([]);
        for (var j = 0 - weekOffset; j < 7 - weekOffset; j++) {
          var currentIndex = i * 7 + j;
          var date = { year: this.year, disabled: false };
          // date in and not in current month
          if (currentIndex < startIndex) {
            date.date = prevMonthLastDate - startIndex + currentIndex + 1;
            if (this.month > 0) {
              date.month = this.month - 1;
            } else {
              date.month = 11;
              date.year--;
            }
          } else if (currentIndex < startIndex + daysNum) {
            date.date = currentIndex - startIndex + 1;
            date.month = this.month;
          } else {
            date.date = currentIndex - startIndex - daysNum + 1;
            if (this.month < 11) {
              date.month = this.month + 1;
            } else {
              date.month = 0;
              date.year++;
            }
          }
          // process limit dates
          var dateObj = new Date(date.year, date.month, date.date);
          var afterFrom = true;
          var beforeTo = true;
          if (this.limit && this.limit.from) {
            afterFrom = dateObj >= this.limit.from;
          }
          if (this.limit && this.limit.to) {
            beforeTo = dateObj < this.limit.to;
          }
          date.disabled = !afterFrom || !beforeTo;
          if (isFunction(this.dateClass)) {
            date.classes = this.dateClass(dateObj, {
              currentMonth: this.month,
              currentYear: this.year,
            });
          } else {
            date.classes = '';
          }
          rows[i].push(date);
        }
      }
      return rows
    },
  },
  methods: {
    getWeekNumber: getWeekNumber,
    tWeekName: function tWeekName(index) {
      return this.t(("uiv.datePicker.week" + index))
    },
    getBtnType: function getBtnType(date) {
      if (
        this.date &&
        date.date === this.date.getDate() &&
        date.month === this.date.getMonth() &&
        date.year === this.date.getFullYear()
      ) {
        return 'primary'
      } else if (
        date.date === this.today.getDate() &&
        date.month === this.today.getMonth() &&
        date.year === this.today.getFullYear()
      ) {
        return 'info'
      } else {
        return 'default'
      }
    },
    select: function select(date) {
      this.$emit('date-change', date);
    },
    goPrevMonth: function goPrevMonth() {
      var month = this.month;
      var year = this.year;
      if (this.month > 0) {
        month--;
      } else {
        month = 11;
        year--;
        this.$emit('year-change', year);
      }
      this.$emit('month-change', month);
    },
    goNextMonth: function goNextMonth() {
      var month = this.month;
      var year = this.year;
      if (this.month < 11) {
        month++;
      } else {
        month = 0;
        year++;
        this.$emit('year-change', year);
      }
      this.$emit('month-change', month);
    },
    changeView: function changeView() {
      this.$emit('view-change', 'm');
    },
  },
};

var _hoisted_1$h = {
  role: "grid",
  style: {"width":"100%"}
};
var _hoisted_2$b = ["colspan"];
var _hoisted_3$7 = { align: "center" };
var _hoisted_4$6 = { key: 0 };
var _hoisted_5$5 = { class: "uiv-datepicker-week" };
var _hoisted_6$5 = {
  key: 0,
  class: "text-center",
  style: {"border-right":"1px solid #eee"}
};
var _hoisted_7$3 = { class: "text-muted" };

function render$k(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_btn = resolveComponent("btn");

  return (openBlock(), createElementBlock("table", _hoisted_1$h, [
    createElementVNode("thead", null, [
      createElementVNode("tr", null, [
        createElementVNode("td", null, [
          createVNode(_component_btn, {
            class: "uiv-datepicker-pager-prev",
            block: "",
            size: "sm",
            style: {"border":"none"},
            onClick: $options.goPrevMonth
          }, {
            default: withCtx(function () { return [
              createElementVNode("i", {
                class: normalizeClass($props.iconControlLeft)
              }, null, 2 /* CLASS */)
            ]; }),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["onClick"])
        ]),
        createElementVNode("td", {
          colspan: $props.weekNumbers ? 6 : 5
        }, [
          createVNode(_component_btn, {
            class: "uiv-datepicker-title",
            block: "",
            size: "sm",
            style: {"border":"none"},
            onClick: $options.changeView
          }, {
            default: withCtx(function () { return [
              createElementVNode("b", null, toDisplayString($options.yearMonthStr), 1 /* TEXT */)
            ]; }),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["onClick"])
        ], 8 /* PROPS */, _hoisted_2$b),
        createElementVNode("td", null, [
          createVNode(_component_btn, {
            class: "uiv-datepicker-pager-next",
            block: "",
            size: "sm",
            style: {"border":"none"},
            onClick: $options.goNextMonth
          }, {
            default: withCtx(function () { return [
              createElementVNode("i", {
                class: normalizeClass($props.iconControlRight)
              }, null, 2 /* CLASS */)
            ]; }),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["onClick"])
        ])
      ]),
      createElementVNode("tr", _hoisted_3$7, [
        ($props.weekNumbers)
          ? (openBlock(), createElementBlock("td", _hoisted_4$6))
          : createCommentVNode("v-if", true),
        (openBlock(true), createElementBlock(Fragment, null, renderList($options.weekDays, function (day, index) {
          return (openBlock(), createElementBlock("td", {
            key: index,
            width: "14.2857142857%"
          }, [
            createElementVNode("small", _hoisted_5$5, toDisplayString($options.tWeekName(day === 0 ? 7 : day)), 1 /* TEXT */)
          ]))
        }), 128 /* KEYED_FRAGMENT */))
      ])
    ]),
    createElementVNode("tbody", null, [
      (openBlock(true), createElementBlock(Fragment, null, renderList($options.monthDayRows, function (row, i) {
        return (openBlock(), createElementBlock("tr", { key: i }, [
          ($props.weekNumbers)
            ? (openBlock(), createElementBlock("td", _hoisted_6$5, [
                createElementVNode("small", _hoisted_7$3, toDisplayString($options.getWeekNumber(row[$props.weekStartsWith])), 1 /* TEXT */)
              ]))
            : createCommentVNode("v-if", true),
          (openBlock(true), createElementBlock(Fragment, null, renderList(row, function (d, j) {
            return (openBlock(), createElementBlock("td", {
              key: (i + "_" + j)
            }, [
              createVNode(_component_btn, {
                block: "",
                size: "sm",
                style: {"border":"none"},
                "data-action": "select",
                class: normalizeClass(d.classes),
                type: $options.getBtnType(d),
                disabled: d.disabled,
                onClick: function ($event) { return ($options.select(d)); }
              }, {
                default: withCtx(function () { return [
                  createElementVNode("span", {
                    "data-action": "select",
                    class: normalizeClass({ 'text-muted': $props.month !== d.month })
                  }, toDisplayString(d.date), 3 /* TEXT, CLASS */)
                ]; }),
                _: 2 /* DYNAMIC */
              }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["class", "type", "disabled", "onClick"])
            ]))
          }), 128 /* KEYED_FRAGMENT */))
        ]))
      }), 128 /* KEYED_FRAGMENT */))
    ])
  ]))
}

script$m.render = render$k;
script$m.__file = "src/components/datepicker/DateView.vue";

var script$l = {
  components: { Btn: script$q },
  mixins: [Local],
  props: {
    month: { type: Number, default: undefined },
    year: { type: Number, default: undefined },
    iconControlLeft: { type: String, default: undefined },
    iconControlRight: { type: String, default: undefined },
  },
  emits: ['year-change', 'month-change', 'view-change'],
  data: function data() {
    return {
      rows: [],
    }
  },
  mounted: function mounted() {
    for (var i = 0; i < 4; i++) {
      this.rows.push([]);
      for (var j = 0; j < 3; j++) {
        this.rows[i].push(i * 3 + j + 1);
      }
    }
  },
  methods: {
    tCell: function tCell(cell) {
      return this.t(("uiv.datePicker.month" + cell))
    },
    getBtnClass: function getBtnClass(month) {
      if (month === this.month) {
        return 'primary'
      } else {
        return 'default'
      }
    },
    goPrevYear: function goPrevYear() {
      this.$emit('year-change', this.year - 1);
    },
    goNextYear: function goNextYear() {
      this.$emit('year-change', this.year + 1);
    },
    changeView: function changeView(monthIndex) {
      if (isExist(monthIndex)) {
        this.$emit('month-change', monthIndex);
        this.$emit('view-change', 'd');
      } else {
        this.$emit('view-change', 'y');
      }
    },
  },
};

var _hoisted_1$g = {
  role: "grid",
  style: {"width":"100%"}
};
var _hoisted_2$a = { colspan: "4" };

function render$j(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_btn = resolveComponent("btn");

  return (openBlock(), createElementBlock("table", _hoisted_1$g, [
    createElementVNode("thead", null, [
      createElementVNode("tr", null, [
        createElementVNode("td", null, [
          createVNode(_component_btn, {
            class: "uiv-datepicker-pager-prev",
            block: "",
            size: "sm",
            style: {"border":"none"},
            onClick: $options.goPrevYear
          }, {
            default: withCtx(function () { return [
              createElementVNode("i", {
                class: normalizeClass($props.iconControlLeft)
              }, null, 2 /* CLASS */)
            ]; }),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["onClick"])
        ]),
        createElementVNode("td", _hoisted_2$a, [
          createVNode(_component_btn, {
            class: "uiv-datepicker-title",
            block: "",
            size: "sm",
            style: {"border":"none"},
            onClick: _cache[0] || (_cache[0] = function ($event) { return ($options.changeView()); })
          }, {
            default: withCtx(function () { return [
              createElementVNode("b", null, toDisplayString($props.year), 1 /* TEXT */)
            ]; }),
            _: 1 /* STABLE */
          })
        ]),
        createElementVNode("td", null, [
          createVNode(_component_btn, {
            class: "uiv-datepicker-pager-next",
            block: "",
            size: "sm",
            style: {"border":"none"},
            onClick: $options.goNextYear
          }, {
            default: withCtx(function () { return [
              createElementVNode("i", {
                class: normalizeClass($props.iconControlRight)
              }, null, 2 /* CLASS */)
            ]; }),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["onClick"])
        ])
      ])
    ]),
    createElementVNode("tbody", null, [
      (openBlock(true), createElementBlock(Fragment, null, renderList($data.rows, function (row, i) {
        return (openBlock(), createElementBlock("tr", { key: i }, [
          (openBlock(true), createElementBlock(Fragment, null, renderList(row, function (m, j) {
            return (openBlock(), createElementBlock("td", {
              key: (i + "_" + j),
              colspan: "2",
              width: "33.333333%"
            }, [
              createVNode(_component_btn, {
                block: "",
                size: "sm",
                style: {"border":"none"},
                type: $options.getBtnClass(i * 3 + j),
                onClick: function ($event) { return ($options.changeView(i * 3 + j)); }
              }, {
                default: withCtx(function () { return [
                  createElementVNode("span", null, toDisplayString($options.tCell(m)), 1 /* TEXT */)
                ]; }),
                _: 2 /* DYNAMIC */
              }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["type", "onClick"])
            ]))
          }), 128 /* KEYED_FRAGMENT */))
        ]))
      }), 128 /* KEYED_FRAGMENT */))
    ])
  ]))
}

script$l.render = render$j;
script$l.__file = "src/components/datepicker/MonthView.vue";

var script$k = {
  components: { Btn: script$q },
  props: {
    year: { type: Number, default: undefined },
    iconControlLeft: { type: String, default: undefined },
    iconControlRight: { type: String, default: undefined },
  },
  emits: ['year-change', 'view-change'],
  computed: {
    rows: function rows() {
      var rows = [];
      var yearGroupStart = this.year - (this.year % 20);
      for (var i = 0; i < 4; i++) {
        rows.push([]);
        for (var j = 0; j < 5; j++) {
          rows[i].push(yearGroupStart + i * 5 + j);
        }
      }
      return rows
    },
    yearStr: function yearStr() {
      var start = this.year - (this.year % 20);
      return (start + " ~ " + (start + 19))
    },
  },
  methods: {
    getBtnClass: function getBtnClass(year) {
      if (year === this.year) {
        return 'primary'
      } else {
        return 'default'
      }
    },
    goPrevYear: function goPrevYear() {
      this.$emit('year-change', this.year - 20);
    },
    goNextYear: function goNextYear() {
      this.$emit('year-change', this.year + 20);
    },
    changeView: function changeView(year) {
      this.$emit('year-change', year);
      this.$emit('view-change', 'm');
    },
  },
};

var _hoisted_1$f = {
  role: "grid",
  style: {"width":"100%"}
};
var _hoisted_2$9 = { colspan: "3" };

function render$i(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_btn = resolveComponent("btn");

  return (openBlock(), createElementBlock("table", _hoisted_1$f, [
    createElementVNode("thead", null, [
      createElementVNode("tr", null, [
        createElementVNode("td", null, [
          createVNode(_component_btn, {
            class: "uiv-datepicker-pager-prev",
            block: "",
            size: "sm",
            style: {"border":"none"},
            onClick: $options.goPrevYear
          }, {
            default: withCtx(function () { return [
              createElementVNode("i", {
                class: normalizeClass($props.iconControlLeft)
              }, null, 2 /* CLASS */)
            ]; }),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["onClick"])
        ]),
        createElementVNode("td", _hoisted_2$9, [
          createVNode(_component_btn, {
            class: "uiv-datepicker-title",
            block: "",
            size: "sm",
            style: {"border":"none"}
          }, {
            default: withCtx(function () { return [
              createElementVNode("b", null, toDisplayString($options.yearStr), 1 /* TEXT */)
            ]; }),
            _: 1 /* STABLE */
          })
        ]),
        createElementVNode("td", null, [
          createVNode(_component_btn, {
            class: "uiv-datepicker-pager-next",
            block: "",
            size: "sm",
            style: {"border":"none"},
            onClick: $options.goNextYear
          }, {
            default: withCtx(function () { return [
              createElementVNode("i", {
                class: normalizeClass($props.iconControlRight)
              }, null, 2 /* CLASS */)
            ]; }),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["onClick"])
        ])
      ])
    ]),
    createElementVNode("tbody", null, [
      (openBlock(true), createElementBlock(Fragment, null, renderList($options.rows, function (row, i) {
        return (openBlock(), createElementBlock("tr", { key: i }, [
          (openBlock(true), createElementBlock(Fragment, null, renderList(row, function (y, j) {
            return (openBlock(), createElementBlock("td", {
              key: (i + "_" + j),
              width: "20%"
            }, [
              createVNode(_component_btn, {
                block: "",
                size: "sm",
                style: {"border":"none"},
                type: $options.getBtnClass(y),
                onClick: function ($event) { return ($options.changeView(y)); }
              }, {
                default: withCtx(function () { return [
                  createElementVNode("span", null, toDisplayString(y), 1 /* TEXT */)
                ]; }),
                _: 2 /* DYNAMIC */
              }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["type", "onClick"])
            ]))
          }), 128 /* KEYED_FRAGMENT */))
        ]))
      }), 128 /* KEYED_FRAGMENT */))
    ])
  ]))
}

script$k.render = render$i;
script$k.__file = "src/components/datepicker/YearView.vue";

var script$j = {
  components: { DateView: script$m, MonthView: script$l, YearView: script$k, Btn: script$q },
  mixins: [Local],
  props: {
    modelValue: { type: null, required: true },
    width: {
      type: Number,
      default: 270,
    },
    todayBtn: {
      type: Boolean,
      default: true,
    },
    clearBtn: {
      type: Boolean,
      default: true,
    },
    closeOnSelected: {
      type: Boolean,
      default: true,
    },
    limitFrom: { type: null, default: undefined },
    limitTo: { type: null, default: undefined },
    format: {
      type: String,
      default: 'yyyy-MM-dd',
    },
    initialView: {
      type: String,
      default: 'd',
    },
    dateParser: {
      type: Function,
      default: Date.parse,
    },
    dateClass: { type: Function, default: undefined },
    yearMonthFormatter: { type: Function, default: undefined },
    weekStartsWith: {
      type: Number,
      default: 0,
      validator: function validator(value) {
        return value >= 0 && value <= 6
      },
    },
    weekNumbers: Boolean,
    iconControlLeft: {
      type: String,
      default: 'glyphicon glyphicon-chevron-left',
    },
    iconControlRight: {
      type: String,
      default: 'glyphicon glyphicon-chevron-right',
    },
  },
  emits: ['update:modelValue'],
  data: function data() {
    return {
      show: false,
      now: new Date(),
      currentMonth: 0,
      currentYear: 0,
      view: 'd',
    }
  },
  computed: {
    valueDateObj: function valueDateObj() {
      var ts = this.dateParser(this.modelValue);
      if (isNaN(ts)) {
        return null
      } else {
        var date = new Date(ts);
        if (date.getHours() !== 0) {
          date = new Date(ts + date.getTimezoneOffset() * 60 * 1000);
        }
        return date
      }
    },
    pickerStyle: function pickerStyle() {
      return {
        width: this.width + 'px',
      }
    },
    pickerClass: function pickerClass() {
      return {
        'uiv-datepicker': true,
        'uiv-datepicker-date': this.view === 'd',
        'uiv-datepicker-month': this.view === 'm',
        'uiv-datepicker-year': this.view === 'y',
      }
    },
    limit: function limit() {
      var limit = {};
      if (this.limitFrom) {
        var limitFrom = this.dateParser(this.limitFrom);
        if (!isNaN(limitFrom)) {
          limitFrom = convertDateToUTC(new Date(limitFrom));
          limitFrom.setHours(0, 0, 0, 0);
          limit.from = limitFrom;
        }
      }
      if (this.limitTo) {
        var limitTo = this.dateParser(this.limitTo);
        if (!isNaN(limitTo)) {
          limitTo = convertDateToUTC(new Date(limitTo));
          limitTo.setHours(0, 0, 0, 0);
          limit.to = limitTo;
        }
      }
      return limit
    },
  },
  watch: {
    modelValue: function modelValue(val, oldVal) {
      this.setMonthAndYearByValue(val, oldVal);
    },
  },
  mounted: function mounted() {
    if (this.modelValue) {
      this.setMonthAndYearByValue(this.modelValue);
    } else {
      this.currentMonth = this.now.getMonth();
      this.currentYear = this.now.getFullYear();
      this.view = this.initialView;
    }
  },
  methods: {
    setMonthAndYearByValue: function setMonthAndYearByValue(val, oldVal) {
      var ts = this.dateParser(val);
      if (!isNaN(ts)) {
        var date = new Date(ts);
        if (date.getHours() !== 0) {
          date = new Date(ts + date.getTimezoneOffset() * 60 * 1000);
        }
        if (
          this.limit &&
          ((this.limit.from && date < this.limit.from) ||
            (this.limit.to && date >= this.limit.to))
        ) {
          this.$emit('update:modelValue', oldVal || '');
        } else {
          this.currentMonth = date.getMonth();
          this.currentYear = date.getFullYear();
        }
      }
    },
    onMonthChange: function onMonthChange(month) {
      this.currentMonth = month;
    },
    onYearChange: function onYearChange(year) {
      this.currentYear = year;
      this.currentMonth = undefined;
    },
    onDateChange: function onDateChange(date) {
      if (
        date &&
        isNumber(date.date) &&
        isNumber(date.month) &&
        isNumber(date.year)
      ) {
        var _date = new Date(date.year, date.month, date.date);
        this.$emit(
          'update:modelValue',
          this.format ? stringify(_date, this.format) : _date
        );
        // if the input event trigger nothing (same value)
        // manually correct
        this.currentMonth = date.month;
        this.currentYear = date.year;
      } else {
        this.$emit('update:modelValue', '');
      }
    },
    onViewChange: function onViewChange(view) {
      this.view = view;
    },
    selectToday: function selectToday() {
      this.view = 'd';
      this.onDateChange({
        date: this.now.getDate(),
        month: this.now.getMonth(),
        year: this.now.getFullYear(),
      });
    },
    clearSelect: function clearSelect() {
      this.currentMonth = this.now.getMonth();
      this.currentYear = this.now.getFullYear();
      this.view = this.initialView;
      this.onDateChange();
    },
    onPickerClick: function onPickerClick(event) {
      if (
        event.target.getAttribute('data-action') !== 'select' ||
        !this.closeOnSelected
      ) {
        event.stopPropagation();
      }
    },
  },
};

var _hoisted_1$e = { key: 0 };
var _hoisted_2$8 = /*#__PURE__*/createElementVNode("br", null, null, -1 /* HOISTED */);
var _hoisted_3$6 = { class: "text-center" };

function render$h(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_date_view = resolveComponent("date-view");
  var _component_month_view = resolveComponent("month-view");
  var _component_year_view = resolveComponent("year-view");
  var _component_btn = resolveComponent("btn");

  return (openBlock(), createElementBlock("div", {
    class: normalizeClass($options.pickerClass),
    style: normalizeStyle($options.pickerStyle),
    "data-role": "date-picker",
    onClick: _cache[0] || (_cache[0] = function () {
      var args = [], len = arguments.length;
      while ( len-- ) args[ len ] = arguments[ len ];

      return ($options.onPickerClick && $options.onPickerClick.apply($options, args));
  })
  }, [
    withDirectives(createVNode(_component_date_view, {
      month: $data.currentMonth,
      year: $data.currentYear,
      date: $options.valueDateObj,
      today: $data.now,
      limit: $options.limit,
      "week-starts-with": $props.weekStartsWith,
      "icon-control-left": $props.iconControlLeft,
      "icon-control-right": $props.iconControlRight,
      "date-class": $props.dateClass,
      "year-month-formatter": $props.yearMonthFormatter,
      "week-numbers": $props.weekNumbers,
      locale: _ctx.locale,
      onMonthChange: $options.onMonthChange,
      onYearChange: $options.onYearChange,
      onDateChange: $options.onDateChange,
      onViewChange: $options.onViewChange
    }, null, 8 /* PROPS */, ["month", "year", "date", "today", "limit", "week-starts-with", "icon-control-left", "icon-control-right", "date-class", "year-month-formatter", "week-numbers", "locale", "onMonthChange", "onYearChange", "onDateChange", "onViewChange"]), [
      [vShow, $data.view === 'd']
    ]),
    withDirectives(createVNode(_component_month_view, {
      month: $data.currentMonth,
      year: $data.currentYear,
      "icon-control-left": $props.iconControlLeft,
      "icon-control-right": $props.iconControlRight,
      locale: _ctx.locale,
      onMonthChange: $options.onMonthChange,
      onYearChange: $options.onYearChange,
      onViewChange: $options.onViewChange
    }, null, 8 /* PROPS */, ["month", "year", "icon-control-left", "icon-control-right", "locale", "onMonthChange", "onYearChange", "onViewChange"]), [
      [vShow, $data.view === 'm']
    ]),
    withDirectives(createVNode(_component_year_view, {
      year: $data.currentYear,
      "icon-control-left": $props.iconControlLeft,
      "icon-control-right": $props.iconControlRight,
      onYearChange: $options.onYearChange,
      onViewChange: $options.onViewChange
    }, null, 8 /* PROPS */, ["year", "icon-control-left", "icon-control-right", "onYearChange", "onViewChange"]), [
      [vShow, $data.view === 'y']
    ]),
    ($props.todayBtn || $props.clearBtn)
      ? (openBlock(), createElementBlock("div", _hoisted_1$e, [
          _hoisted_2$8,
          createElementVNode("div", _hoisted_3$6, [
            ($props.todayBtn)
              ? (openBlock(), createBlock(_component_btn, {
                  key: 0,
                  "data-action": "select",
                  "data-type": "today",
                  type: "info",
                  size: "sm",
                  onClick: $options.selectToday,
                  textContent: toDisplayString(_ctx.t('uiv.datePicker.today'))
                }, null, 8 /* PROPS */, ["onClick", "textContent"]))
              : createCommentVNode("v-if", true),
            ($props.clearBtn)
              ? (openBlock(), createBlock(_component_btn, {
                  key: 1,
                  "data-action": "select",
                  "data-type": "clear",
                  size: "sm",
                  onClick: $options.clearSelect,
                  textContent: toDisplayString(_ctx.t('uiv.datePicker.clear'))
                }, null, 8 /* PROPS */, ["onClick", "textContent"]))
              : createCommentVNode("v-if", true)
          ])
        ]))
      : createCommentVNode("v-if", true)
  ], 6 /* CLASS, STYLE */))
}

script$j.render = render$h;
script$j.__file = "src/components/datepicker/DatePicker.vue";

var HANDLER = '_uiv_scroll_handler';
var events$1 = [EVENTS.RESIZE, EVENTS.SCROLL];

var bind$3 = function (el, binding) {
  var callback = binding.value;
  if (!isFunction(callback)) {
    return
  }
  unbind$3(el);
  el[HANDLER] = callback;
  events$1.forEach(function (event) {
    on(window, event, el[HANDLER]);
  });
};

var unbind$3 = function (el) {
  events$1.forEach(function (event) {
    off(window, event, el[HANDLER]);
  });
  delete el[HANDLER];
};

var update$3 = function (el, binding) {
  if (binding.value !== binding.oldValue) {
    bind$3(el, binding);
  }
};

var scroll = { mounted: bind$3, unmounted: unbind$3, updated: update$3 };

var script$i = {
  directives: {
    scroll: scroll,
  },
  props: {
    offset: {
      type: Number,
      default: 0,
    },
  },
  data: function data() {
    return {
      affixed: false,
    }
  },
  computed: {
    classes: function classes() {
      return {
        affix: this.affixed,
      }
    },
    styles: function styles() {
      return {
        top: this.affixed ? this.offset + 'px' : null,
      }
    },
  },
  methods: {
    // from https://github.com/ant-design/ant-design/blob/master/components/affix/index.jsx#L20
    onScroll: function onScroll() {
      var this$1$1 = this;

      // if is hidden don't calculate anything
      if (
        !(
          this.$el.offsetWidth ||
          this.$el.offsetHeight ||
          this.$el.getClientRects().length
        )
      ) {
        return
      }
      // get window scroll and element position to detect if have to be normal or affixed
      var scroll = {};
      var element = {};
      var rect = this.$el.getBoundingClientRect();
      var body = document.body;
      var types = ['Top', 'Left'];
      types.forEach(function (type) {
        var t = type.toLowerCase();
        scroll[t] = window['page' + (type === 'Top' ? 'Y' : 'X') + 'Offset'];
        element[t] =
          scroll[t] +
          rect[t] -
          (this$1$1.$el['client' + type] || body['client' + type] || 0);
      });
      var fix = scroll.top > element.top - this.offset;
      if (this.affixed !== fix) {
        this.affixed = fix;
        this.$emit(this.affixed ? 'affix' : 'unfix');
        this.$nextTick(function () {
          this$1$1.$emit(this$1$1.affixed ? 'affixed' : 'unfixed');
        });
      }
    },
  },
};

var _hoisted_1$d = { class: "hidden-print" };

function render$g(_ctx, _cache, $props, $setup, $data, $options) {
  var _directive_scroll = resolveDirective("scroll");

  return (openBlock(), createElementBlock("div", _hoisted_1$d, [
    withDirectives(createElementVNode("div", {
      class: normalizeClass($options.classes),
      style: normalizeStyle($options.styles)
    }, [
      renderSlot(_ctx.$slots, "default")
    ], 6 /* CLASS, STYLE */), [
      [_directive_scroll, $options.onScroll]
    ])
  ]))
}

script$i.render = render$g;
script$i.__file = "src/components/affix/Affix.vue";

var script$h = {
  props: {
    dismissible: {
      type: Boolean,
      default: false,
    },
    duration: {
      type: Number,
      default: 0,
    },
    type: {
      type: String,
      default: 'info',
    },
  },
  emits: ['dismissed'],
  data: function data() {
    return {
      timeout: 0,
    }
  },
  computed: {
    alertClass: function alertClass() {
      var obj;

      return ( obj = {
        alert: true
      }, obj[("alert-" + (this.type))] = Boolean(this.type), obj['alert-dismissible'] = this.dismissible, obj )
    },
  },
  mounted: function mounted() {
    if (this.duration > 0) {
      this.timeout = setTimeout(this.closeAlert, this.duration);
    }
  },
  unmounted: function unmounted() {
    clearTimeout(this.timeout);
  },
  methods: {
    closeAlert: function closeAlert() {
      clearTimeout(this.timeout);
      this.$emit('dismissed');
    },
  },
};

var _hoisted_1$c = /*#__PURE__*/createElementVNode("span", { "aria-hidden": "true" }, "×", -1 /* HOISTED */);
var _hoisted_2$7 = [
  _hoisted_1$c
];

function render$f(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("div", {
    role: "alert",
    class: normalizeClass($options.alertClass)
  }, [
    ($props.dismissible)
      ? (openBlock(), createElementBlock("button", {
          key: 0,
          type: "button",
          class: "close",
          "aria-label": "Close",
          onClick: _cache[0] || (_cache[0] = function () {
            var args = [], len = arguments.length;
            while ( len-- ) args[ len ] = arguments[ len ];

            return ($options.closeAlert && $options.closeAlert.apply($options, args));
  })
        }, _hoisted_2$7))
      : createCommentVNode("v-if", true),
    renderSlot(_ctx.$slots, "default")
  ], 2 /* CLASS */))
}

script$h.render = render$f;
script$h.__file = "src/components/alert/Alert.vue";

var script$g = {
  props: {
    modelValue: {
      type: Number,
      required: true,
      validator: function (v) { return v >= 1; },
    },
    boundaryLinks: {
      type: Boolean,
      default: false,
    },
    directionLinks: {
      type: Boolean,
      default: true,
    },
    size: { type: String, default: undefined },
    align: { type: String, default: undefined },
    totalPage: {
      type: Number,
      required: true,
      validator: function (v) { return v >= 0; },
    },
    maxSize: {
      type: Number,
      default: 5,
      validator: function (v) { return v >= 0; },
    },
    disabled: Boolean,
  },
  emits: ['update:modelValue', 'change'],
  data: function data() {
    return {
      sliceStart: 0,
    }
  },
  computed: {
    navClasses: function navClasses() {
      var obj;

      return ( obj = {}, obj[("text-" + (this.align))] = Boolean(this.align), obj )
    },
    classes: function classes() {
      var obj;

      return ( obj = {}, obj[("pagination-" + (this.size))] = Boolean(this.size), obj )
    },
    sliceArray: function sliceArray() {
      return range(this.totalPage).slice(
        this.sliceStart,
        this.sliceStart + this.maxSize
      )
    },
  },
  created: function created() {
    this.$watch(
      function (vm) { return [vm.modelValue, vm.maxSize, vm.totalPage].join(); },
      this.calculateSliceStart,
      {
        immediate: true,
      }
    );
  },
  methods: {
    calculateSliceStart: function calculateSliceStart() {
      var currentPage = this.modelValue;
      var chunkSize = this.maxSize;
      var currentChunkStart = this.sliceStart;
      var currentChunkEnd = currentChunkStart + chunkSize;
      if (currentPage > currentChunkEnd) {
        var lastChunkStart = this.totalPage - chunkSize;
        if (currentPage > lastChunkStart) {
          this.sliceStart = lastChunkStart;
        } else {
          this.sliceStart = currentPage - 1;
        }
      } else if (currentPage < currentChunkStart + 1) {
        if (currentPage > chunkSize) {
          this.sliceStart = currentPage - chunkSize;
        } else {
          this.sliceStart = 0;
        }
      }
    },
    onPageChange: function onPageChange(page) {
      if (
        !this.disabled &&
        page > 0 &&
        page <= this.totalPage &&
        page !== this.modelValue
      ) {
        this.$emit('update:modelValue', page);
        this.$emit('change', page);
      }
    },
    toPage: function toPage(pre) {
      if (this.disabled) {
        return
      }
      var chunkSize = this.maxSize;
      var currentChunkStart = this.sliceStart;
      var lastChunkStart = this.totalPage - chunkSize;
      var start = pre
        ? currentChunkStart - chunkSize
        : currentChunkStart + chunkSize;
      if (start < 0) {
        this.sliceStart = 0;
      } else if (start > lastChunkStart) {
        this.sliceStart = lastChunkStart;
      } else {
        this.sliceStart = start;
      }
    },
  },
};

var _hoisted_1$b = /*#__PURE__*/createElementVNode("span", { "aria-hidden": "true" }, "«", -1 /* HOISTED */);
var _hoisted_2$6 = [
  _hoisted_1$b
];
var _hoisted_3$5 = /*#__PURE__*/createElementVNode("span", { "aria-hidden": "true" }, "‹", -1 /* HOISTED */);
var _hoisted_4$5 = [
  _hoisted_3$5
];
var _hoisted_5$4 = /*#__PURE__*/createElementVNode("span", { "aria-hidden": "true" }, "…", -1 /* HOISTED */);
var _hoisted_6$4 = [
  _hoisted_5$4
];
var _hoisted_7$2 = ["onClick"];
var _hoisted_8$2 = /*#__PURE__*/createElementVNode("span", { "aria-hidden": "true" }, "…", -1 /* HOISTED */);
var _hoisted_9$2 = [
  _hoisted_8$2
];
var _hoisted_10$2 = /*#__PURE__*/createElementVNode("span", { "aria-hidden": "true" }, "›", -1 /* HOISTED */);
var _hoisted_11$1 = [
  _hoisted_10$2
];
var _hoisted_12$1 = /*#__PURE__*/createElementVNode("span", { "aria-hidden": "true" }, "»", -1 /* HOISTED */);
var _hoisted_13$1 = [
  _hoisted_12$1
];

function render$e(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("nav", {
    "aria-label": "Page navigation",
    class: normalizeClass($options.navClasses)
  }, [
    createElementVNode("ul", {
      class: normalizeClass(["pagination", $options.classes])
    }, [
      ($props.boundaryLinks)
        ? (openBlock(), createElementBlock("li", {
            key: 0,
            class: normalizeClass({ disabled: $props.modelValue <= 1 || $props.disabled })
          }, [
            createElementVNode("a", {
              href: "#",
              role: "button",
              "aria-label": "First",
              onClick: _cache[0] || (_cache[0] = withModifiers(function ($event) { return ($options.onPageChange(1)); }, ["prevent"]))
            }, _hoisted_2$6)
          ], 2 /* CLASS */))
        : createCommentVNode("v-if", true),
      ($props.directionLinks)
        ? (openBlock(), createElementBlock("li", {
            key: 1,
            class: normalizeClass({ disabled: $props.modelValue <= 1 || $props.disabled })
          }, [
            createElementVNode("a", {
              href: "#",
              role: "button",
              "aria-label": "Previous",
              onClick: _cache[1] || (_cache[1] = withModifiers(function ($event) { return ($options.onPageChange($props.modelValue - 1)); }, ["prevent"]))
            }, _hoisted_4$5)
          ], 2 /* CLASS */))
        : createCommentVNode("v-if", true),
      ($data.sliceStart > 0)
        ? (openBlock(), createElementBlock("li", {
            key: 2,
            class: normalizeClass({ disabled: $props.disabled })
          }, [
            createElementVNode("a", {
              href: "#",
              role: "button",
              "aria-label": "Previous group",
              onClick: _cache[2] || (_cache[2] = withModifiers(function ($event) { return ($options.toPage(1)); }, ["prevent"]))
            }, _hoisted_6$4)
          ], 2 /* CLASS */))
        : createCommentVNode("v-if", true),
      (openBlock(true), createElementBlock(Fragment, null, renderList($options.sliceArray, function (item) {
        return (openBlock(), createElementBlock("li", {
          key: item,
          class: normalizeClass({ active: $props.modelValue === item + 1, disabled: $props.disabled })
        }, [
          createElementVNode("a", {
            href: "#",
            role: "button",
            onClick: withModifiers(function ($event) { return ($options.onPageChange(item + 1)); }, ["prevent"])
          }, toDisplayString(item + 1), 9 /* TEXT, PROPS */, _hoisted_7$2)
        ], 2 /* CLASS */))
      }), 128 /* KEYED_FRAGMENT */)),
      ($data.sliceStart < $props.totalPage - $props.maxSize)
        ? (openBlock(), createElementBlock("li", {
            key: 3,
            class: normalizeClass({ disabled: $props.disabled })
          }, [
            createElementVNode("a", {
              href: "#",
              role: "button",
              "aria-label": "Next group",
              onClick: _cache[3] || (_cache[3] = withModifiers(function ($event) { return ($options.toPage(0)); }, ["prevent"]))
            }, _hoisted_9$2)
          ], 2 /* CLASS */))
        : createCommentVNode("v-if", true),
      ($props.directionLinks)
        ? (openBlock(), createElementBlock("li", {
            key: 4,
            class: normalizeClass({ disabled: $props.modelValue >= $props.totalPage || $props.disabled })
          }, [
            createElementVNode("a", {
              href: "#",
              role: "button",
              "aria-label": "Next",
              onClick: _cache[4] || (_cache[4] = withModifiers(function ($event) { return ($options.onPageChange(_ctx.value + 1)); }, ["prevent"]))
            }, _hoisted_11$1)
          ], 2 /* CLASS */))
        : createCommentVNode("v-if", true),
      ($props.boundaryLinks)
        ? (openBlock(), createElementBlock("li", {
            key: 5,
            class: normalizeClass({ disabled: $props.modelValue >= $props.totalPage || $props.disabled })
          }, [
            createElementVNode("a", {
              href: "#",
              role: "button",
              "aria-label": "Last",
              onClick: _cache[5] || (_cache[5] = withModifiers(function ($event) { return ($options.onPageChange($props.totalPage)); }, ["prevent"]))
            }, _hoisted_13$1)
          ], 2 /* CLASS */))
        : createCommentVNode("v-if", true)
    ], 2 /* CLASS */)
  ], 2 /* CLASS */))
}

script$g.render = render$e;
script$g.__file = "src/components/pagination/Pagination.vue";

var SHOW_CLASS = 'in';

var popupMixin = {
  props: {
    modelValue: {
      type: Boolean,
      default: false,
    },
    tag: {
      type: String,
      default: 'span',
    },
    placement: {
      type: String,
      default: PLACEMENTS$1.TOP,
    },
    autoPlacement: {
      type: Boolean,
      default: true,
    },
    appendTo: {
      type: null,
      default: 'body',
    },
    positionBy: {
      type: null,
      default: null,
    },
    transition: {
      type: Number,
      default: 150,
    },
    hideDelay: {
      type: Number,
      default: 0,
    },
    showDelay: {
      type: Number,
      default: 0,
    },
    enable: {
      type: Boolean,
      default: true,
    },
    enterable: {
      type: Boolean,
      default: true,
    },
    target: null,
    viewport: null,
    customClass: String,
  },
  data: function data() {
    return {
      triggerEl: null,
      hideTimeoutId: 0,
      showTimeoutId: 0,
      transitionTimeoutId: 0,
      autoTimeoutId: 0,
    }
  },
  watch: {
    modelValue: function modelValue(v) {
      v ? this.show() : this.hide();
    },
    trigger: function trigger() {
      this.clearListeners();
      this.initListeners();
    },
    target: function target(value) {
      this.clearListeners();
      this.initTriggerElByTarget(value);
      this.initListeners();
    },
    allContent: function allContent(value) {
      var this$1$1 = this;

      // can not use value because it can not detect slot changes
      if (this.isNotEmpty()) {
        // reset position while content changed & is shown
        // nextTick is required
        this.$nextTick(function () {
          /* istanbul ignore else */
          if (this$1$1.isShown()) {
            this$1$1.resetPosition();
          }
        });
      } else {
        this.hide();
      }
    },
    enable: function enable(value) {
      // hide if enable changed to false
      /* istanbul ignore else */
      if (!value) {
        this.hide();
      }
    },
  },
  mounted: function mounted() {
    var this$1$1 = this;

    ensureElementMatchesFunction();
    removeFromDom(this.$refs.popup);
    this.$nextTick(function () {
      this$1$1.initTriggerElByTarget(this$1$1.target);
      this$1$1.initListeners();
      if (this$1$1.modelValue) {
        this$1$1.show();
      }
    });
  },
  beforeDestroy: function beforeDestroy() {
    this.clearListeners();
    removeFromDom(this.$refs.popup);
  },
  methods: {
    initTriggerElByTarget: function initTriggerElByTarget(target) {
      if (target) {
        // target exist
        this.triggerEl = getElementBySelectorOrRef(target);
      } else {
        // find special element
        var trigger = this.$el.querySelector('[data-role="trigger"]');
        if (trigger) {
          this.triggerEl = trigger;
        } else {
          // use the first child
          var firstChild = this.$el.querySelector('*');
          this.triggerEl = firstChild === this.$refs.popup ? null : firstChild;
        }
      }
    },
    initListeners: function initListeners() {
      if (this.triggerEl) {
        if (this.trigger === TRIGGERS.HOVER) {
          on(this.triggerEl, EVENTS.MOUSE_ENTER, this.show);
          on(this.triggerEl, EVENTS.MOUSE_LEAVE, this.hide);
        } else if (this.trigger === TRIGGERS.FOCUS) {
          on(this.triggerEl, EVENTS.FOCUS, this.show);
          on(this.triggerEl, EVENTS.BLUR, this.hide);
        } else if (this.trigger === TRIGGERS.HOVER_FOCUS) {
          on(this.triggerEl, EVENTS.MOUSE_ENTER, this.handleAuto);
          on(this.triggerEl, EVENTS.MOUSE_LEAVE, this.handleAuto);
          on(this.triggerEl, EVENTS.FOCUS, this.handleAuto);
          on(this.triggerEl, EVENTS.BLUR, this.handleAuto);
        } else if (
          this.trigger === TRIGGERS.CLICK ||
          this.trigger === TRIGGERS.OUTSIDE_CLICK
        ) {
          on(this.triggerEl, EVENTS.CLICK, this.toggle);
        }
      }
      on(window, EVENTS.CLICK, this.windowClicked);
    },
    clearListeners: function clearListeners() {
      if (this.triggerEl) {
        off(this.triggerEl, EVENTS.FOCUS, this.show);
        off(this.triggerEl, EVENTS.BLUR, this.hide);
        off(this.triggerEl, EVENTS.MOUSE_ENTER, this.show);
        off(this.triggerEl, EVENTS.MOUSE_LEAVE, this.hide);
        off(this.triggerEl, EVENTS.CLICK, this.toggle);
        off(this.triggerEl, EVENTS.MOUSE_ENTER, this.handleAuto);
        off(this.triggerEl, EVENTS.MOUSE_LEAVE, this.handleAuto);
        off(this.triggerEl, EVENTS.FOCUS, this.handleAuto);
        off(this.triggerEl, EVENTS.BLUR, this.handleAuto);
      }
      off(window, EVENTS.CLICK, this.windowClicked);
      this.clearTimeouts();
    },
    clearTimeouts: function clearTimeouts() {
      if (this.hideTimeoutId) {
        clearTimeout(this.hideTimeoutId);
        this.hideTimeoutId = 0;
      }
      if (this.showTimeoutId) {
        clearTimeout(this.showTimeoutId);
        this.showTimeoutId = 0;
      }
      if (this.transitionTimeoutId) {
        clearTimeout(this.transitionTimeoutId);
        this.transitionTimeoutId = 0;
      }
      if (this.autoTimeoutId) {
        clearTimeout(this.autoTimeoutId);
        this.autoTimeoutId = 0;
      }
    },
    resetPosition: function resetPosition() {
      var popup = this.$refs.popup;
      /* istanbul ignore else */
      if (popup) {
        setTooltipPosition(
          popup,
          this.triggerEl,
          this.placement,
          this.autoPlacement,
          this.appendTo,
          this.positionBy,
          this.viewport
        );
        popup.offsetHeight;
      }
    },
    hideOnLeave: function hideOnLeave() {
      if (
        this.trigger === TRIGGERS.HOVER ||
        (this.trigger === TRIGGERS.HOVER_FOCUS &&
          !this.triggerEl.matches(':focus'))
      ) {
        this.$hide();
      }
    },
    toggle: function toggle() {
      if (this.isShown()) {
        this.hide();
      } else {
        this.show();
      }
    },
    show: function show() {
      var this$1$1 = this;

      if (
        this.enable &&
        this.triggerEl &&
        this.isNotEmpty() &&
        !this.isShown()
      ) {
        var popUpAppendedContainer = this.hideTimeoutId > 0; // weird condition
        if (popUpAppendedContainer) {
          clearTimeout(this.hideTimeoutId);
          this.hideTimeoutId = 0;
        }
        if (this.transitionTimeoutId > 0) {
          clearTimeout(this.transitionTimeoutId);
          this.transitionTimeoutId = 0;
        }
        clearTimeout(this.showTimeoutId);
        this.showTimeoutId = setTimeout(function () {
          this$1$1.showTimeoutId = 0;
          var popup = this$1$1.$refs.popup;
          if (popup) {
            var alreadyOpenModalNum = getOpenModalNum();
            if (alreadyOpenModalNum > 1) {
              var defaultZ = this$1$1.name === 'popover' ? 1060 : 1070;
              var offset = (alreadyOpenModalNum - 1) * 20;
              popup.style.zIndex = "" + (defaultZ + offset);
            }
            // add to dom
            if (!popUpAppendedContainer) {
              popup.className = (this$1$1.name) + " " + (this$1$1.placement) + " " + (this$1$1.customClass ? this$1$1.customClass : '') + " fade";
              var container = getElementBySelectorOrRef(this$1$1.appendTo);
              container.appendChild(popup);
              this$1$1.resetPosition();
            }
            addClass(popup, SHOW_CLASS);
            this$1$1.$emit('update:modelValue', true);
            this$1$1.$emit('show');
          }
        }, this.showDelay);
      }
    },
    hide: function hide() {
      var this$1$1 = this;

      if (this.showTimeoutId > 0) {
        clearTimeout(this.showTimeoutId);
        this.showTimeoutId = 0;
      }

      if (!this.isShown()) {
        return
      }
      if (
        this.enterable &&
        (this.trigger === TRIGGERS.HOVER ||
          this.trigger === TRIGGERS.HOVER_FOCUS)
      ) {
        clearTimeout(this.hideTimeoutId);
        this.hideTimeoutId = setTimeout(function () {
          this$1$1.hideTimeoutId = 0;
          var popup = this$1$1.$refs.popup;
          if (popup && !popup.matches(':hover')) {
            this$1$1.$hide();
          }
        }, 100);
      } else {
        this.$hide();
      }
    },
    $hide: function $hide() {
      var this$1$1 = this;

      if (this.isShown()) {
        clearTimeout(this.hideTimeoutId);
        this.hideTimeoutId = setTimeout(function () {
          this$1$1.hideTimeoutId = 0;
          removeClass(this$1$1.$refs.popup, SHOW_CLASS);
          // gives fade out time
          this$1$1.transitionTimeoutId = setTimeout(function () {
            this$1$1.transitionTimeoutId = 0;
            removeFromDom(this$1$1.$refs.popup);
            this$1$1.$emit('update:modelValue', false);
            this$1$1.$emit('hide');
          }, this$1$1.transition);
        }, this.hideDelay);
      }
    },
    isShown: function isShown() {
      return hasClass(this.$refs.popup, SHOW_CLASS)
    },
    windowClicked: function windowClicked(event) {
      if (
        this.triggerEl &&
        isFunction(this.triggerEl.contains) &&
        !this.triggerEl.contains(event.target) &&
        this.trigger === TRIGGERS.OUTSIDE_CLICK &&
        !(this.$refs.popup && this.$refs.popup.contains(event.target)) &&
        this.isShown()
      ) {
        this.hide();
      }
    },
    handleAuto: function handleAuto() {
      var this$1$1 = this;

      clearTimeout(this.autoTimeoutId);
      this.autoTimeoutId = setTimeout(function () {
        this$1$1.autoTimeoutId = 0;
        if (this$1$1.triggerEl.matches(':hover, :focus')) {
          this$1$1.show();
        } else {
          this$1$1.hide();
        }
      }, 20); // 20ms make firefox happy
    },
  },
};

var script$f = {
  mixins: [popupMixin],
  props: {
    text: {
      type: String,
      default: '',
    },
    trigger: {
      type: String,
      default: TRIGGERS.HOVER_FOCUS,
    },
  },
  data: function data() {
    return {
      name: 'tooltip',
    }
  },
  computed: {
    allContent: function allContent() {
      return this.text
    },
  },
  // beforeUnmount() {
  //   console.log('unmount')
  // },
  methods: {
    isNotEmpty: function isNotEmpty() {
      return this.text
    },
  },
  render: function render() {
    return h(this.tag, [
      this.$slots.default && this.$slots.default(),
      h(
        'div',
        {
          ref: 'popup',
          role: 'tooltip',
          onMouseleave: this.hideOnLeave,
        },
        [
          h('div', { class: 'tooltip-arrow' }),
          h(
            'div',
            {
              class: 'tooltip-inner',
            },
            this.text
          ) ]
      ) ])
  },
};

script$f.__file = "src/components/tooltip/Tooltip.vue";

var script$e = {
  mixins: [popupMixin],
  props: {
    title: {
      type: String,
      default: '',
    },
    content: {
      type: String,
      default: '',
    },
    trigger: {
      type: String,
      default: TRIGGERS.OUTSIDE_CLICK,
    },
  },
  data: function data() {
    return {
      name: 'popover',
    }
  },
  computed: {
    allContent: function allContent() {
      return this.title + this.content
    },
  },
  // beforeUnmount() {
  //   console.log('unmount')
  // },
  methods: {
    isNotEmpty: function isNotEmpty() {
      return this.title || this.content || this.$slots.popover
    },
  },
  render: function render() {
    return h(this.tag, [
      this.$slots.default && this.$slots.default(),
      h(
        'div',
        {
          style: {
            display: 'block',
          },
          ref: 'popup',
          onMouseleave: this.hideOnLeave,
        },
        [
          h('div', { class: 'arrow' }),
          this.title
            ? h(
                'h3',
                {
                  class: 'popover-title',
                  directives: [{ name: 'show', value: this.title }],
                },
                this.title
              )
            : null,
          h('div', { class: 'popover-content' }, [
            this.content || (this.$slots.popover && this.$slots.popover()) ]) ]
      ) ])
  },
};

script$e.__file = "src/components/popover/Popover.vue";

var maxHours = 23;
var zero = 0;
var maxMinutes = 59;
var cutUpAmAndPm = 12;

var script$d = {
  components: { Btn: script$q },
  mixins: [Local],
  props: {
    modelValue: {
      type: Date,
      required: true,
    },
    showMeridian: {
      type: Boolean,
      default: true,
    },
    min: { type: null, default: undefined },
    max: { type: null, default: undefined },
    hourStep: {
      type: Number,
      default: 1,
    },
    minStep: {
      type: Number,
      default: 1,
    },
    readonly: {
      type: Boolean,
      default: false,
    },
    controls: {
      type: Boolean,
      default: true,
    },
    iconControlUp: {
      type: String,
      default: 'glyphicon glyphicon-chevron-up',
    },
    iconControlDown: {
      type: String,
      default: 'glyphicon glyphicon-chevron-down',
    },
    inputWidth: {
      type: Number,
      default: 50,
    },
  },
  emits: ['update:modelValue'],
  data: function data() {
    return {
      hours: 0,
      minutes: 0,
      meridian: true,
      hoursText: '',
      minutesText: '',
    }
  },
  computed: {
    inputStyles: function inputStyles() {
      return {
        width: ((this.inputWidth) + "px"),
      }
    },
  },
  watch: {
    modelValue: function modelValue(value) {
      this.updateByValue(value);
    },
    showMeridian: function showMeridian(value) {
      this.setTime();
    },
    hoursText: function hoursText(value) {
      if (this.hours === 0 && value === '') {
        // Prevent a runtime reset from being overwritten
        return
      }
      var hour = parseInt(value);
      if (this.showMeridian) {
        if (hour >= 1 && hour <= cutUpAmAndPm) {
          if (this.meridian) {
            this.hours = hour === cutUpAmAndPm ? 0 : hour;
          } else {
            this.hours =
              hour === cutUpAmAndPm ? cutUpAmAndPm : hour + cutUpAmAndPm;
          }
        }
      } else if (hour >= zero && hour <= maxHours) {
        this.hours = hour;
      }
      this.setTime();
    },
    minutesText: function minutesText(value) {
      if (this.minutes === 0 && value === '') {
        // Prevent a runtime reset from being overwritten
        return
      }
      var minutesStr = parseInt(value);
      if (minutesStr >= zero && minutesStr <= maxMinutes) {
        this.minutes = minutesStr;
      }
      this.setTime();
    },
  },
  mounted: function mounted() {
    this.updateByValue(this.modelValue);
  },
  methods: {
    updateByValue: function updateByValue(value) {
      if (isNaN(value.getTime())) {
        this.hours = 0;
        this.minutes = 0;
        this.hoursText = '';
        this.minutesText = '';
        this.meridian = true;
        return
      }
      this.hours = value.getHours();
      this.minutes = value.getMinutes();
      if (!this.showMeridian) {
        this.hoursText = pad(this.hours, 2);
      } else {
        if (this.hours >= cutUpAmAndPm) {
          if (this.hours === cutUpAmAndPm) {
            this.hoursText = this.hours + '';
          } else {
            this.hoursText = pad(this.hours - cutUpAmAndPm, 2);
          }
          this.meridian = false;
        } else {
          if (this.hours === zero) {
            this.hoursText = cutUpAmAndPm.toString();
          } else {
            this.hoursText = pad(this.hours, 2);
          }
          this.meridian = true;
        }
      }
      this.minutesText = pad(this.minutes, 2);
      // lazy model won't update when using keyboard up/down
      this.$refs.hoursInput.value = this.hoursText;
      this.$refs.minutesInput.value = this.minutesText;
    },
    addHour: function addHour(step) {
      step = step || this.hourStep;
      this.hours = this.hours >= maxHours ? zero : this.hours + step;
    },
    reduceHour: function reduceHour(step) {
      step = step || this.hourStep;
      this.hours = this.hours <= zero ? maxHours : this.hours - step;
    },
    addMinute: function addMinute() {
      if (this.minutes >= maxMinutes) {
        this.minutes = zero;
        this.addHour(1);
      } else {
        this.minutes += this.minStep;
      }
    },
    reduceMinute: function reduceMinute() {
      if (this.minutes <= zero) {
        this.minutes = maxMinutes + 1 - this.minStep;
        this.reduceHour(1);
      } else {
        this.minutes -= this.minStep;
      }
    },
    changeTime: function changeTime(isHour, isPlus) {
      if (!this.readonly) {
        if (isHour && isPlus) {
          this.addHour();
        } else if (isHour && !isPlus) {
          this.reduceHour();
        } else if (!isHour && isPlus) {
          this.addMinute();
        } else {
          this.reduceMinute();
        }
        this.setTime();
      }
    },
    toggleMeridian: function toggleMeridian() {
      this.meridian = !this.meridian;
      if (this.meridian) {
        this.hours -= cutUpAmAndPm;
      } else {
        this.hours += cutUpAmAndPm;
      }
      this.setTime();
    },
    onWheel: function onWheel(e, isHour) {
      if (!this.readonly) {
        e.preventDefault();
        this.changeTime(isHour, e.deltaY < 0);
      }
    },
    setTime: function setTime() {
      var time = this.modelValue;
      if (isNaN(time.getTime())) {
        time = new Date();
        time.setHours(0);
        time.setMinutes(0);
      }
      time.setHours(this.hours);
      time.setMinutes(this.minutes);
      if (this.max instanceof Date) {
        var max = new Date(time);
        max.setHours(this.max.getHours());
        max.setMinutes(this.max.getMinutes());
        time = time > max ? max : time;
      }
      if (this.min instanceof Date) {
        var min = new Date(time);
        min.setHours(this.min.getHours());
        min.setMinutes(this.min.getMinutes());
        time = time < min ? min : time;
      }
      this.$emit('update:modelValue', new Date(time));
    },
    selectInputValue: function selectInputValue(e) {
      // mouseup should be prevented!
      // See various comments in https://stackoverflow.com/questions/3272089/programmatically-selecting-text-in-an-input-field-on-ios-devices-mobile-safari
      e.target.setSelectionRange(0, 2);
    },
  },
};

var _hoisted_1$a = {
  key: 0,
  class: "text-center"
};
var _hoisted_2$5 = /*#__PURE__*/createElementVNode("td", null, " ", -1 /* HOISTED */);
var _hoisted_3$4 = { key: 0 };
var _hoisted_4$4 = { class: "form-group" };
var _hoisted_5$3 = ["readonly"];
var _hoisted_6$3 = /*#__PURE__*/createElementVNode("td", null, [
  /*#__PURE__*/createTextVNode(" "),
  /*#__PURE__*/createElementVNode("b", null, ":"),
  /*#__PURE__*/createTextVNode(" ")
], -1 /* HOISTED */);
var _hoisted_7$1 = { class: "form-group" };
var _hoisted_8$1 = ["readonly"];
var _hoisted_9$1 = { key: 0 };
var _hoisted_10$1 = /*#__PURE__*/createTextVNode("   ");
var _hoisted_11 = {
  key: 1,
  class: "text-center"
};
var _hoisted_12 = /*#__PURE__*/createElementVNode("td", null, " ", -1 /* HOISTED */);
var _hoisted_13 = { key: 0 };

function render$d(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_btn = resolveComponent("btn");

  return (openBlock(), createElementBlock("section", {
    onClick: _cache[14] || (_cache[14] = withModifiers(function () {}, ["stop"]))
  }, [
    createElementVNode("table", null, [
      createElementVNode("tbody", null, [
        ($props.controls)
          ? (openBlock(), createElementBlock("tr", _hoisted_1$a, [
              createElementVNode("td", null, [
                createVNode(_component_btn, {
                  type: "link",
                  size: "sm",
                  disabled: $props.readonly,
                  onClick: _cache[0] || (_cache[0] = function ($event) { return ($options.changeTime(1, 1)); })
                }, {
                  default: withCtx(function () { return [
                    createElementVNode("i", {
                      class: normalizeClass($props.iconControlUp)
                    }, null, 2 /* CLASS */)
                  ]; }),
                  _: 1 /* STABLE */
                }, 8 /* PROPS */, ["disabled"])
              ]),
              _hoisted_2$5,
              createElementVNode("td", null, [
                createVNode(_component_btn, {
                  type: "link",
                  size: "sm",
                  disabled: $props.readonly,
                  onClick: _cache[1] || (_cache[1] = function ($event) { return ($options.changeTime(0, 1)); })
                }, {
                  default: withCtx(function () { return [
                    createElementVNode("i", {
                      class: normalizeClass($props.iconControlUp)
                    }, null, 2 /* CLASS */)
                  ]; }),
                  _: 1 /* STABLE */
                }, 8 /* PROPS */, ["disabled"])
              ]),
              ($props.showMeridian)
                ? (openBlock(), createElementBlock("td", _hoisted_3$4))
                : createCommentVNode("v-if", true)
            ]))
          : createCommentVNode("v-if", true),
        createElementVNode("tr", null, [
          createElementVNode("td", _hoisted_4$4, [
            withDirectives(createElementVNode("input", {
              ref: "hoursInput",
              "onUpdate:modelValue": _cache[2] || (_cache[2] = function ($event) { return (($data.hoursText) = $event); }),
              type: "tel",
              pattern: "\\d*",
              class: "form-control text-center",
              style: normalizeStyle($options.inputStyles),
              placeholder: "HH",
              readonly: $props.readonly,
              maxlength: "2",
              size: "2",
              onMouseup: _cache[3] || (_cache[3] = function () {
                var args = [], len = arguments.length;
                while ( len-- ) args[ len ] = arguments[ len ];

                return ($options.selectInputValue && $options.selectInputValue.apply($options, args));
  }),
              onKeydown: [
                _cache[4] || (_cache[4] = withKeys(withModifiers(function ($event) { return ($options.changeTime(1, 1)); }, ["prevent"]), ["up"])),
                _cache[5] || (_cache[5] = withKeys(withModifiers(function ($event) { return ($options.changeTime(1, 0)); }, ["prevent"]), ["down"]))
              ],
              onWheel: _cache[6] || (_cache[6] = function ($event) { return ($options.onWheel($event, true)); })
            }, null, 44 /* STYLE, PROPS, HYDRATE_EVENTS */, _hoisted_5$3), [
              [
                vModelText,
                $data.hoursText,
                void 0,
                { lazy: true }
              ]
            ])
          ]),
          _hoisted_6$3,
          createElementVNode("td", _hoisted_7$1, [
            withDirectives(createElementVNode("input", {
              ref: "minutesInput",
              "onUpdate:modelValue": _cache[7] || (_cache[7] = function ($event) { return (($data.minutesText) = $event); }),
              type: "tel",
              pattern: "\\d*",
              class: "form-control text-center",
              style: normalizeStyle($options.inputStyles),
              placeholder: "MM",
              readonly: $props.readonly,
              maxlength: "2",
              size: "2",
              onMouseup: _cache[8] || (_cache[8] = function () {
                var args = [], len = arguments.length;
                while ( len-- ) args[ len ] = arguments[ len ];

                return ($options.selectInputValue && $options.selectInputValue.apply($options, args));
  }),
              onKeydown: [
                _cache[9] || (_cache[9] = withKeys(withModifiers(function ($event) { return ($options.changeTime(0, 1)); }, ["prevent"]), ["up"])),
                _cache[10] || (_cache[10] = withKeys(withModifiers(function ($event) { return ($options.changeTime(0, 0)); }, ["prevent"]), ["down"]))
              ],
              onWheel: _cache[11] || (_cache[11] = function ($event) { return ($options.onWheel($event, false)); })
            }, null, 44 /* STYLE, PROPS, HYDRATE_EVENTS */, _hoisted_8$1), [
              [
                vModelText,
                $data.minutesText,
                void 0,
                { lazy: true }
              ]
            ])
          ]),
          ($props.showMeridian)
            ? (openBlock(), createElementBlock("td", _hoisted_9$1, [
                _hoisted_10$1,
                createVNode(_component_btn, {
                  "data-action": "toggleMeridian",
                  disabled: $props.readonly,
                  onClick: $options.toggleMeridian,
                  textContent: toDisplayString(
                $data.meridian ? _ctx.t('uiv.timePicker.am') : _ctx.t('uiv.timePicker.pm')
              )
                }, null, 8 /* PROPS */, ["disabled", "onClick", "textContent"])
              ]))
            : createCommentVNode("v-if", true)
        ]),
        ($props.controls)
          ? (openBlock(), createElementBlock("tr", _hoisted_11, [
              createElementVNode("td", null, [
                createVNode(_component_btn, {
                  type: "link",
                  size: "sm",
                  disabled: $props.readonly,
                  onClick: _cache[12] || (_cache[12] = function ($event) { return ($options.changeTime(1, 0)); })
                }, {
                  default: withCtx(function () { return [
                    createElementVNode("i", {
                      class: normalizeClass($props.iconControlDown)
                    }, null, 2 /* CLASS */)
                  ]; }),
                  _: 1 /* STABLE */
                }, 8 /* PROPS */, ["disabled"])
              ]),
              _hoisted_12,
              createElementVNode("td", null, [
                createVNode(_component_btn, {
                  type: "link",
                  size: "sm",
                  disabled: $props.readonly,
                  onClick: _cache[13] || (_cache[13] = function ($event) { return ($options.changeTime(0, 0)); })
                }, {
                  default: withCtx(function () { return [
                    createElementVNode("i", {
                      class: normalizeClass($props.iconControlDown)
                    }, null, 2 /* CLASS */)
                  ]; }),
                  _: 1 /* STABLE */
                }, 8 /* PROPS */, ["disabled"])
              ]),
              ($props.showMeridian)
                ? (openBlock(), createElementBlock("td", _hoisted_13))
                : createCommentVNode("v-if", true)
            ]))
          : createCommentVNode("v-if", true)
      ])
    ])
  ]))
}

script$d.render = render$d;
script$d.__file = "src/components/timepicker/TimePicker.vue";

function request(url, method) {
  if ( method === void 0 ) method = 'GET';

  var request = new window.XMLHttpRequest();
  var data = {};
  var p = {
    then: function (fn1, fn2) { return p.done(fn1).fail(fn2); },
    catch: function (fn) { return p.fail(fn); },
    always: function (fn) { return p.done(fn).fail(fn); },
  };
  var statuses = ['done', 'fail'];
  statuses.forEach(function (name) {
    data[name] = [];
    p[name] = function (fn) {
      if (fn instanceof Function) { data[name].push(fn); }
      return p
    };
  });
  p.done(JSON.parse);
  request.onreadystatechange = function () {
    if (request.readyState === 4) {
      var e = { status: request.status };
      if (request.status === 200) {
        var response = request.responseText;
        for (var i in data.done) {
          /* istanbul ignore else */
          if (hasOwnProperty(data.done, i) && isFunction(data.done[i])) {
            var value = data.done[i](response);
            if (isExist(value)) {
              response = value;
            }
          }
        }
      } else {
        data.fail.forEach(function (fail) { return fail(e); });
      }
    }
  };
  request.open(method, url);
  request.setRequestHeader('Accept', 'application/json');
  request.send();
  return p
}

var script$c = {
  components: { Dropdown: script$s },
  props: {
    modelValue: {
      type: null,
      required: true,
    },
    data: { type: Array, default: function () { return []; } },
    itemKey: { type: String, default: undefined },
    appendToBody: {
      type: Boolean,
      default: false,
    },
    ignoreCase: {
      type: Boolean,
      default: true,
    },
    matchStart: {
      type: Boolean,
      default: false,
    },
    forceSelect: {
      type: Boolean,
      default: false,
    },
    forceClear: {
      type: Boolean,
      default: false,
    },
    limit: {
      type: Number,
      default: 10,
    },
    asyncSrc: { type: String, default: undefined },
    asyncKey: { type: String, default: undefined },
    asyncFunction: { type: Function, default: undefined },
    debounce: {
      type: Number,
      default: 200,
    },
    openOnFocus: {
      type: Boolean,
      default: true,
    },
    openOnEmpty: {
      type: Boolean,
      default: false,
    },
    target: {
      required: true,
      type: null,
    },
    preselect: {
      type: Boolean,
      default: true,
    },
  },
  emits: [
    'update:modelValue',
    'loading',
    'loaded',
    'loaded-error',
    'selected-item-changed' ],
  data: function data() {
    return {
      inputEl: null,
      items: [],
      activeIndex: 0,
      timeoutID: 0,
      elements: [],
      open: false,
      dropdownMenuEl: null,
    }
  },
  computed: {
    regexOptions: function regexOptions() {
      var options = '';
      if (this.ignoreCase) {
        options += 'i';
      }
      if (!this.matchStart) {
        options += 'g';
      }
      return options
    },
  },
  watch: {
    target: function target(el) {
      this.removeListeners();
      this.initInputElByTarget(el);
      this.initListeners();
    },
    modelValue: function modelValue(value) {
      this.setInputTextByValue(value);
    },
    activeIndex: function activeIndex(index) {
      index >= 0 && this.$emit('selected-item-changed', index);
    },
  },
  mounted: function mounted() {
    var this$1$1 = this;

    ensureElementMatchesFunction();
    this.$nextTick(function () {
      this$1$1.initInputElByTarget(this$1$1.target);
      this$1$1.initListeners();
      this$1$1.dropdownMenuEl =
        this$1$1.$refs.dropdown.$el.querySelector('.dropdown-menu');
      // set input text if v-model not empty
      if (this$1$1.modelValue) {
        this$1$1.setInputTextByValue(this$1$1.modelValue);
      }
    });
  },
  beforeUnmount: function beforeUnmount() {
    this.removeListeners();
  },
  methods: {
    setInputTextByValue: function setInputTextByValue(value) {
      if (isString(value)) {
        // direct
        this.inputEl.value = value;
      } else if (value) {
        // is object
        this.inputEl.value = this.itemKey ? value[this.itemKey] : value;
      } else if (value === null) {
        // is null or undefined or something else not valid
        this.inputEl.value = '';
      }
    },
    hasEmptySlot: function hasEmptySlot() {
      return !!this.$slots.empty || !!this.$slots.empty
    },
    initInputElByTarget: function initInputElByTarget(target) {
      if (!target) {
        return
      }
      this.inputEl = getElementBySelectorOrRef(target);
    },
    initListeners: function initListeners() {
      if (this.inputEl) {
        this.elements = [this.inputEl];
        on(this.inputEl, EVENTS.FOCUS, this.inputFocused);
        on(this.inputEl, EVENTS.BLUR, this.inputBlured);
        on(this.inputEl, EVENTS.INPUT, this.inputChanged);
        on(this.inputEl, EVENTS.KEY_DOWN, this.inputKeyPressed);
      }
    },
    removeListeners: function removeListeners() {
      this.elements = [];
      if (this.inputEl) {
        off(this.inputEl, EVENTS.FOCUS, this.inputFocused);
        off(this.inputEl, EVENTS.BLUR, this.inputBlured);
        off(this.inputEl, EVENTS.INPUT, this.inputChanged);
        off(this.inputEl, EVENTS.KEY_DOWN, this.inputKeyPressed);
      }
    },
    prepareItems: function prepareItems(data, disableFilters) {
      if ( disableFilters === void 0 ) disableFilters = false;

      if (disableFilters) {
        this.items = data.slice(0, this.limit);
        return
      }
      this.items = [];
      this.activeIndex = this.preselect ? 0 : -1;
      for (var i = 0, l = data.length; i < l; i++) {
        var item = data[i];
        var key = this.itemKey ? item[this.itemKey] : item;
        key = key.toString();
        var index = -1;
        if (this.ignoreCase) {
          index = key.toLowerCase().indexOf(this.inputEl.value.toLowerCase());
        } else {
          index = key.indexOf(this.inputEl.value);
        }
        if (this.matchStart ? index === 0 : index >= 0) {
          this.items.push(item);
        }
        if (this.items.length >= this.limit) {
          break
        }
      }
    },
    fetchItems: function fetchItems(value, debounce) {
      var this$1$1 = this;

      clearTimeout(this.timeoutID);
      if (value === '' && !this.openOnEmpty) {
        this.open = false;
      } else if (this.data) {
        this.prepareItems(this.data);
        this.open = this.hasEmptySlot() || Boolean(this.items.length);
      } else if (this.asyncSrc) {
        this.timeoutID = setTimeout(function () {
          this$1$1.$emit('loading');
          request(this$1$1.asyncSrc + encodeURIComponent(value))
            .then(function (data) {
              if (this$1$1.inputEl.matches(':focus')) {
                this$1$1.prepareItems(
                  this$1$1.asyncKey ? data[this$1$1.asyncKey] : data,
                  true
                );
                this$1$1.open = this$1$1.hasEmptySlot() || Boolean(this$1$1.items.length);
              }
              this$1$1.$emit('loaded');
            })
            .catch(function (err) {
              console.error(err);
              this$1$1.$emit('loaded-error');
            });
        }, debounce);
      } else if (this.asyncFunction) {
        var cb = function (data) {
          if (this$1$1.inputEl.matches(':focus')) {
            this$1$1.prepareItems(data, true);
            this$1$1.open = this$1$1.hasEmptySlot() || Boolean(this$1$1.items.length);
          }
          this$1$1.$emit('loaded');
        };
        this.timeoutID = setTimeout(function () {
          this$1$1.$emit('loading');
          this$1$1.asyncFunction(value, cb);
        }, debounce);
      }
    },
    inputChanged: function inputChanged() {
      var value = this.inputEl.value;
      this.fetchItems(value, this.debounce);
      this.$emit('update:modelValue', this.forceSelect ? undefined : value);
    },
    inputFocused: function inputFocused() {
      if (this.openOnFocus) {
        var value = this.inputEl.value;
        this.fetchItems(value, 0);
      }
    },
    inputBlured: function inputBlured() {
      var this$1$1 = this;

      if (!this.dropdownMenuEl.matches(':hover')) {
        this.open = false;
      }
      if (this.inputEl && this.forceClear) {
        this.$nextTick(function () {
          if (typeof this$1$1.modelValue === 'undefined') {
            this$1$1.inputEl.value = '';
          }
        });
      }
    },
    inputKeyPressed: function inputKeyPressed(event) {
      event.stopPropagation();
      if (this.open) {
        switch (event.keyCode) {
          case 13:
            if (this.activeIndex >= 0) {
              this.selectItem(this.items[this.activeIndex]);
            } else {
              this.open = false;
            }
            event.preventDefault();
            break
          case 27:
            this.open = false;
            break
          case 38:
            this.activeIndex = this.activeIndex > 0 ? this.activeIndex - 1 : 0;
            break
          case 40: {
            var maxIndex = this.items.length - 1;
            this.activeIndex =
              this.activeIndex < maxIndex ? this.activeIndex + 1 : maxIndex;
            break
          }
        }
      }
    },
    selectItem: function selectItem(item) {
      this.$emit('update:modelValue', item);
      this.open = false;
    },
    highlight: function highlight(item) {
      var value = this.itemKey ? item[this.itemKey] : item;
      var inputValue = this.inputEl.value.replace(
        /[-[\]{}()*+?.,\\^$|#\s]/g,
        '\\$&'
      );
      return value.replace(
        new RegExp(("" + inputValue), this.regexOptions),
        '<b>$&</b>'
      )
    },
  },
};

var _hoisted_1$9 = ["onClick"];
var _hoisted_2$4 = ["innerHTML"];

function render$c(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_dropdown = resolveComponent("dropdown");

  return (openBlock(), createBlock(_component_dropdown, {
    ref: "dropdown",
    modelValue: $data.open,
    "onUpdate:modelValue": _cache[0] || (_cache[0] = function ($event) { return (($data.open) = $event); }),
    tag: "section",
    "append-to-body": $props.appendToBody,
    "not-close-elements": $data.elements,
    "position-element": $data.inputEl
  }, {
    dropdown: withCtx(function () { return [
      renderSlot(_ctx.$slots, "item", {
        items: $data.items,
        activeIndex: $data.activeIndex,
        select: $options.selectItem,
        highlight: $options.highlight
      }, function () { return [
        (openBlock(true), createElementBlock(Fragment, null, renderList($data.items, function (item, index) {
          return (openBlock(), createElementBlock("li", {
            key: index,
            class: normalizeClass({ active: $data.activeIndex === index })
          }, [
            createElementVNode("a", {
              href: "#",
              onClick: withModifiers(function ($event) { return ($options.selectItem(item)); }, ["prevent"])
            }, [
              createElementVNode("span", {
                innerHTML: $options.highlight(item)
              }, null, 8 /* PROPS */, _hoisted_2$4)
            ], 8 /* PROPS */, _hoisted_1$9)
          ], 2 /* CLASS */))
        }), 128 /* KEYED_FRAGMENT */))
      ]; }),
      (!$data.items || $data.items.length === 0)
        ? renderSlot(_ctx.$slots, "empty", { key: 0 })
        : createCommentVNode("v-if", true)
    ]; }),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["modelValue", "append-to-body", "not-close-elements", "position-element"]))
}

script$c.render = render$c;
script$c.__file = "src/components/typeahead/Typeahead.vue";

var script$b = {
  props: {
    modelValue: {
      type: Number,
      required: true,
      validator: function validator(value) {
        return value >= 0 && value <= 100
      },
    },
    labelText: { type: String, default: undefined },
    type: { type: String, default: undefined },
    label: {
      type: Boolean,
      default: false,
    },
    minWidth: {
      type: Boolean,
      default: false,
    },
    striped: {
      type: Boolean,
      default: false,
    },
    active: {
      type: Boolean,
      default: false,
    },
  },
};

var _hoisted_1$8 = ["aria-valuenow"];

function render$b(_ctx, _cache, $props, $setup, $data, $options) {
  var obj;

  return (openBlock(), createElementBlock("div", {
    class: normalizeClass(( obj = {
      'progress-bar': true,
      'progress-bar-striped': $props.striped,
      active: $props.striped && $props.active
    }, obj[("progress-bar-" + ($props.type))] = Boolean($props.type), obj )),
    style: normalizeStyle({
      minWidth: $props.minWidth ? '2em' : null,
      width: (($props.modelValue) + "%"),
    }),
    role: "progressbar",
    "aria-valuemin": "0",
    "aria-valuenow": $props.modelValue,
    "aria-valuemax": "100"
  }, toDisplayString($props.label ? ($props.labelText ? $props.labelText : (($props.modelValue) + "%")) : null), 15 /* TEXT, CLASS, STYLE, PROPS */, _hoisted_1$8))
}

script$b.render = render$b;
script$b.__file = "src/components/progressbar/ProgressBarStack.vue";

var script$a = {
  components: { ProgressBarStack: script$b },
  props: {
    modelValue: {
      type: Number,
      validator: function validator(value) {
        return value >= 0 && value <= 100
      },
      default: 0,
    },
    labelText: { type: String, default: undefined },
    type: { type: String, default: undefined },
    label: {
      type: Boolean,
      default: false,
    },
    minWidth: {
      type: Boolean,
      default: false,
    },
    striped: {
      type: Boolean,
      default: false,
    },
    active: {
      type: Boolean,
      default: false,
    },
  },
};

var _hoisted_1$7 = { class: "progress" };

function render$a(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_ProgressBarStack = resolveComponent("ProgressBarStack");

  return (openBlock(), createElementBlock("div", _hoisted_1$7, [
    (_ctx.$slots.default)
      ? renderSlot(_ctx.$slots, "default", { key: 0 })
      : (openBlock(), createBlock(_component_ProgressBarStack, normalizeProps(mergeProps({ key: 1 }, _ctx.$props)), null, 16 /* FULL_PROPS */))
  ]))
}

script$a.render = render$a;
script$a.__file = "src/components/progressbar/ProgressBar.vue";

var script$9 = {
  mixins: [linkMixin],
  props: {
    active: {
      type: Boolean,
      default: false,
    },
  },
};

var _hoisted_1$6 = ["href", "target"];

function render$9(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_router_link = resolveComponent("router-link");

  return (openBlock(), createElementBlock("li", {
    class: normalizeClass({ active: $props.active })
  }, [
    ($props.active)
      ? renderSlot(_ctx.$slots, "default", { key: 0 })
      : (_ctx.to)
        ? (openBlock(), createBlock(_component_router_link, {
            key: 1,
            to: _ctx.to,
            replace: _ctx.replace,
            append: _ctx.append,
            exact: _ctx.exact
          }, {
            default: withCtx(function () { return [
              renderSlot(_ctx.$slots, "default")
            ]; }),
            _: 3 /* FORWARDED */
          }, 8 /* PROPS */, ["to", "replace", "append", "exact"]))
        : (openBlock(), createElementBlock("a", {
            key: 2,
            href: _ctx.href,
            target: _ctx.target
          }, [
            renderSlot(_ctx.$slots, "default")
          ], 8 /* PROPS */, _hoisted_1$6))
  ], 2 /* CLASS */))
}

script$9.render = render$9;
script$9.__file = "src/components/breadcrumbs/BreadcrumbItem.vue";

var script$8 = {
  functional: true,
  components: { BreadcrumbItem: script$9 },
  props: {
    items: { type: Array, default: function () { return []; } },
  },
  methods: {
    hasOwnProperty: hasOwnProperty,
  },
};

var _hoisted_1$5 = { class: "breadcrumb" };

function render$8(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_BreadcrumbItem = resolveComponent("BreadcrumbItem");

  return (openBlock(), createElementBlock("ol", _hoisted_1$5, [
    renderSlot(_ctx.$slots, "default"),
    (openBlock(true), createElementBlock(Fragment, null, renderList($props.items, function (item, index) {
      return (openBlock(), createBlock(_component_BreadcrumbItem, {
        key: $options.hasOwnProperty(item, 'key') ? item.key : index,
        active: 
        $options.hasOwnProperty(item, 'active')
          ? item.active
          : index === $props.items.length - 1
      ,
        href: item.href,
        to: item.to,
        replace: item.replace,
        append: item.append,
        exact: item.exact
      }, {
        default: withCtx(function () { return [
          createTextVNode(toDisplayString(item.text), 1 /* TEXT */)
        ]; }),
        _: 2 /* DYNAMIC */
      }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["active", "href", "to", "replace", "append", "exact"]))
    }), 128 /* KEYED_FRAGMENT */))
  ]))
}

script$8.render = render$8;
script$8.__file = "src/components/breadcrumbs/Breadcrumbs.vue";

var _hoisted_1$4 = {
  class: "btn-toolbar",
  role: "toolbar"
};

function render$7(_ctx, _cache) {
  return (openBlock(), createElementBlock("div", _hoisted_1$4, [
    renderSlot(_ctx.$slots, "default")
  ]))
}

var script$7 = {};


script$7.render = render$7;
script$7.__file = "src/components/button/BtnToolbar.vue";

var script$6 = {
  components: { Dropdown: script$s },
  mixins: [Local],
  props: {
    modelValue: {
      type: Array,
      required: true,
    },
    options: {
      type: Array,
      required: true,
    },
    labelKey: {
      type: String,
      default: 'label',
    },
    valueKey: {
      type: String,
      default: 'value',
    },
    limit: {
      type: Number,
      default: 0,
    },
    size: { type: String, default: undefined },
    placeholder: { type: String, default: undefined },
    split: {
      type: String,
      default: ', ',
    },
    disabled: {
      type: Boolean,
      default: false,
    },
    appendToBody: {
      type: Boolean,
      default: false,
    },
    block: {
      type: Boolean,
      default: false,
    },
    collapseSelected: {
      type: Boolean,
      default: false,
    },
    filterable: {
      type: Boolean,
      default: false,
    },
    filterAutoFocus: {
      type: Boolean,
      default: true,
    },
    filterFunction: { type: Function, default: undefined },
    filterPlaceholder: { type: String, default: undefined },
    selectedIcon: {
      type: String,
      default: 'glyphicon glyphicon-ok',
    },
    itemSelectedClass: { type: String, default: undefined },
  },
  emits: [
    'focus',
    'blur',
    'visible-change',
    'update:modelValue',
    'change',
    'limit-exceed',
    'search' ],
  data: function data() {
    return {
      showDropdown: false,
      els: [],
      filterInput: '',
      currentActive: -1,
    }
  },
  computed: {
    containerStyles: function containerStyles() {
      return {
        width: this.block ? '100%' : '',
      }
    },
    filteredOptions: function filteredOptions() {
      var this$1$1 = this;

      if (this.filterable && this.filterInput) {
        if (this.filterFunction) {
          return this.filterFunction(this.filterInput)
        } else {
          var filterInput = this.filterInput.toLowerCase();
          return this.options.filter(
            function (v) { return v[this$1$1.valueKey].toString().toLowerCase().indexOf(filterInput) >=
                0 ||
              v[this$1$1.labelKey].toString().toLowerCase().indexOf(filterInput) >=
                0; }
          )
        }
      } else {
        return this.options
      }
    },
    groupedOptions: function groupedOptions() {
      var this$1$1 = this;

      return this.filteredOptions
        .map(function (v) { return v.group; })
        .filter(onlyUnique)
        .map(function (v) { return ({
          options: this$1$1.filteredOptions.filter(function (option) { return option.group === v; }),
          $group: v,
        }); })
    },
    flattenGroupedOptions: function flattenGroupedOptions() {
      var ref;

      return (ref = []).concat.apply(ref, this.groupedOptions.map(function (v) { return v.options; }))
    },
    selectClasses: function selectClasses() {
      var obj;

      return ( obj = {}, obj[("input-" + (this.size))] = this.size, obj )
    },
    selectedIconClasses: function selectedIconClasses() {
      var obj;

      return ( obj = {}, obj[this.selectedIcon] = true, obj['pull-right'] = true, obj )
    },
    selectTextClasses: function selectTextClasses() {
      return {
        'text-muted': this.modelValue.length === 0,
      }
    },
    labelValue: function labelValue() {
      var this$1$1 = this;

      var optionsByValue = this.options.map(function (v) { return v[this$1$1.valueKey]; });
      return this.modelValue.map(function (v) {
        var index = optionsByValue.indexOf(v);
        return index >= 0 ? this$1$1.options[index][this$1$1.labelKey] : v
      })
    },
    selectedText: function selectedText() {
      if (this.modelValue.length) {
        var labelValue = this.labelValue;
        if (this.collapseSelected) {
          var str = labelValue[0];
          str +=
            labelValue.length > 1
              ? ((this.split) + "+" + (labelValue.length - 1))
              : '';
          return str
        } else {
          return labelValue.join(this.split)
        }
      } else {
        return this.placeholder || this.t('uiv.multiSelect.placeholder')
      }
    },
    customOptionsVisible: function customOptionsVisible() {
      return !!this.$slots.option || !!this.$slots.option
    },
  },
  watch: {
    showDropdown: function showDropdown(v) {
      var this$1$1 = this;

      // clear filter input when dropdown toggles
      this.filterInput = '';
      this.currentActive = -1;
      this.$emit('visible-change', v);
      if (v && this.filterable && this.filterAutoFocus) {
        this.$nextTick(function () {
          this$1$1.$refs.filterInput.focus();
        });
      }
    },
  },
  mounted: function mounted() {
    this.els = [this.$el];
  },
  methods: {
    goPrevOption: function goPrevOption() {
      if (!this.showDropdown) {
        return
      }
      this.currentActive > 0
        ? this.currentActive--
        : (this.currentActive = this.flattenGroupedOptions.length - 1);
    },
    goNextOption: function goNextOption() {
      if (!this.showDropdown) {
        return
      }
      this.currentActive < this.flattenGroupedOptions.length - 1
        ? this.currentActive++
        : (this.currentActive = 0);
    },
    selectOption: function selectOption() {
      var index = this.currentActive;
      var options = this.flattenGroupedOptions;
      if (!this.showDropdown) {
        this.showDropdown = true;
      } else if (index >= 0 && index < options.length) {
        this.toggle(options[index]);
      }
    },
    itemClasses: function itemClasses(item) {
      var result = {
        disabled: item.disabled,
        active: this.currentActive === this.flattenGroupedOptions.indexOf(item),
      };
      if (this.itemSelectedClass) {
        result[this.itemSelectedClass] = this.isItemSelected(item);
      }
      return result
    },
    isItemSelected: function isItemSelected(item) {
      return this.modelValue.indexOf(item[this.valueKey]) >= 0
    },
    toggle: function toggle(item) {
      if (item.disabled) {
        return
      }
      var value = item[this.valueKey];
      var index = this.modelValue.indexOf(value);
      if (this.limit === 1) {
        var newValue = index >= 0 ? [] : [value];
        this.$emit('update:modelValue', newValue);
        this.$emit('change', newValue);
      } else {
        if (index >= 0) {
          var newVal = this.modelValue.slice();
          newVal.splice(index, 1);
          this.$emit('update:modelValue', newVal);
          this.$emit('change', newVal);
        } else if (this.limit === 0 || this.modelValue.length < this.limit) {
          var newVal$1 = this.modelValue.slice();
          newVal$1.push(value);
          this.$emit('update:modelValue', newVal$1);
          this.$emit('change', newVal$1);
        } else {
          this.$emit('limit-exceed');
        }
      }
    },
    searchClicked: function searchClicked() {
      this.$emit('search', this.filterInput);
    },
  },
};

var _hoisted_1$3 = ["disabled"];
var _hoisted_2$3 = /*#__PURE__*/createElementVNode("div", {
  class: "pull-right",
  style: {"display":"inline-block","vertical-align":"middle"}
}, [
  /*#__PURE__*/createElementVNode("span", null, " "),
  /*#__PURE__*/createElementVNode("span", { class: "caret" })
], -1 /* HOISTED */);
var _hoisted_3$3 = ["textContent"];
var _hoisted_4$3 = {
  key: 0,
  style: {"padding":"4px 8px"}
};
var _hoisted_5$2 = ["placeholder"];
var _hoisted_6$2 = ["textContent"];
var _hoisted_7 = ["onClick"];
var _hoisted_8 = {
  key: 0,
  role: "button",
  style: {"outline":"0"}
};
var _hoisted_9 = {
  key: 1,
  role: "button",
  style: {"outline":"0"}
};
var _hoisted_10 = {
  key: 2,
  role: "button",
  style: {"outline":"0"}
};

function render$6(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_dropdown = resolveComponent("dropdown");

  return (openBlock(), createBlock(_component_dropdown, {
    ref: "dropdown",
    modelValue: $data.showDropdown,
    "onUpdate:modelValue": _cache[14] || (_cache[14] = function ($event) { return (($data.showDropdown) = $event); }),
    "not-close-elements": $data.els,
    "append-to-body": $props.appendToBody,
    disabled: $props.disabled,
    style: normalizeStyle($options.containerStyles),
    onKeydown: _cache[15] || (_cache[15] = withKeys(function ($event) { return ($data.showDropdown = false); }, ["esc"]))
  }, {
    dropdown: withCtx(function () { return [
      ($props.filterable)
        ? (openBlock(), createElementBlock("li", _hoisted_4$3, [
            withDirectives(createElementVNode("input", {
              ref: "filterInput",
              "onUpdate:modelValue": _cache[5] || (_cache[5] = function ($event) { return (($data.filterInput) = $event); }),
              "aria-label": "Filter...",
              class: "form-control input-sm",
              type: "text",
              placeholder: 
            $props.filterPlaceholder || _ctx.t('uiv.multiSelect.filterPlaceholder')
          ,
              onKeyup: _cache[6] || (_cache[6] = withKeys(function () {
                var args = [], len = arguments.length;
                while ( len-- ) args[ len ] = arguments[ len ];

                return ($options.searchClicked && $options.searchClicked.apply($options, args));
      }, ["enter"])),
              onKeydown: [
                _cache[7] || (_cache[7] = withKeys(withModifiers(function () {
                  var args = [], len = arguments.length;
                  while ( len-- ) args[ len ] = arguments[ len ];

                  return ($options.goNextOption && $options.goNextOption.apply($options, args));
      }, ["prevent","stop"]), ["down"])),
                _cache[8] || (_cache[8] = withKeys(withModifiers(function () {
                  var args = [], len = arguments.length;
                  while ( len-- ) args[ len ] = arguments[ len ];

                  return ($options.goPrevOption && $options.goPrevOption.apply($options, args));
      }, ["prevent","stop"]), ["up"])),
                _cache[9] || (_cache[9] = withKeys(withModifiers(function () {
                  var args = [], len = arguments.length;
                  while ( len-- ) args[ len ] = arguments[ len ];

                  return ($options.selectOption && $options.selectOption.apply($options, args));
      }, ["prevent","stop"]), ["enter"]))
              ]
            }, null, 40 /* PROPS, HYDRATE_EVENTS */, _hoisted_5$2), [
              [vModelText, $data.filterInput]
            ])
          ]))
        : createCommentVNode("v-if", true),
      (openBlock(true), createElementBlock(Fragment, null, renderList($options.groupedOptions, function (item, i) {
        return (openBlock(), createElementBlock(Fragment, null, [
          (item.$group)
            ? (openBlock(), createElementBlock("li", {
                key: i,
                class: "dropdown-header",
                textContent: toDisplayString(item.$group)
              }, null, 8 /* PROPS */, _hoisted_6$2))
            : createCommentVNode("v-if", true),
          (openBlock(true), createElementBlock(Fragment, null, renderList(item.options, function (_item, j) {
            return (openBlock(), createElementBlock("li", {
              key: (i + "_" + j),
              class: normalizeClass($options.itemClasses(_item)),
              style: {"outline":"0"},
              onKeydown: [
                _cache[10] || (_cache[10] = withKeys(withModifiers(function () {
                  var args = [], len = arguments.length;
                  while ( len-- ) args[ len ] = arguments[ len ];

                  return ($options.goNextOption && $options.goNextOption.apply($options, args));
            }, ["prevent","stop"]), ["down"])),
                _cache[11] || (_cache[11] = withKeys(withModifiers(function () {
                  var args = [], len = arguments.length;
                  while ( len-- ) args[ len ] = arguments[ len ];

                  return ($options.goPrevOption && $options.goPrevOption.apply($options, args));
            }, ["prevent","stop"]), ["up"])),
                _cache[12] || (_cache[12] = withKeys(withModifiers(function () {
                  var args = [], len = arguments.length;
                  while ( len-- ) args[ len ] = arguments[ len ];

                  return ($options.selectOption && $options.selectOption.apply($options, args));
            }, ["prevent","stop"]), ["enter"]))
              ],
              onClick: withModifiers(function ($event) { return ($options.toggle(_item, $event)); }, ["stop"]),
              onMouseenter: _cache[13] || (_cache[13] = function ($event) { return ($data.currentActive = -1); })
            }, [
              ($options.customOptionsVisible)
                ? (openBlock(), createElementBlock("a", _hoisted_8, [
                    renderSlot(_ctx.$slots, "option", { item: _item }),
                    ($props.selectedIcon && $options.isItemSelected(_item))
                      ? (openBlock(), createElementBlock("span", {
                          key: 0,
                          class: normalizeClass($options.selectedIconClasses)
                        }, null, 2 /* CLASS */))
                      : createCommentVNode("v-if", true)
                  ]))
                : ($options.isItemSelected(_item))
                  ? (openBlock(), createElementBlock("a", _hoisted_9, [
                      createElementVNode("b", null, toDisplayString(_item[$props.labelKey]), 1 /* TEXT */),
                      ($props.selectedIcon)
                        ? (openBlock(), createElementBlock("span", {
                            key: 0,
                            class: normalizeClass($options.selectedIconClasses)
                          }, null, 2 /* CLASS */))
                        : createCommentVNode("v-if", true)
                    ]))
                  : (openBlock(), createElementBlock("a", _hoisted_10, [
                      createElementVNode("span", null, toDisplayString(_item[$props.labelKey]), 1 /* TEXT */)
                    ]))
            ], 42 /* CLASS, PROPS, HYDRATE_EVENTS */, _hoisted_7))
          }), 128 /* KEYED_FRAGMENT */))
        ], 64 /* STABLE_FRAGMENT */))
      }), 256 /* UNKEYED_FRAGMENT */))
    ]; }),
    default: withCtx(function () { return [
      createElementVNode("div", {
        class: normalizeClass(["form-control dropdown-toggle clearfix", $options.selectClasses]),
        disabled: $props.disabled ? true : undefined,
        tabindex: "0",
        "data-role": "trigger",
        onFocus: _cache[0] || (_cache[0] = function ($event) { return (_ctx.$emit('focus', $event)); }),
        onBlur: _cache[1] || (_cache[1] = function ($event) { return (_ctx.$emit('blur', $event)); }),
        onKeydown: [
          _cache[2] || (_cache[2] = withKeys(withModifiers(function () {
            var args = [], len = arguments.length;
            while ( len-- ) args[ len ] = arguments[ len ];

            return ($options.goNextOption && $options.goNextOption.apply($options, args));
      }, ["prevent","stop"]), ["down"])),
          _cache[3] || (_cache[3] = withKeys(withModifiers(function () {
            var args = [], len = arguments.length;
            while ( len-- ) args[ len ] = arguments[ len ];

            return ($options.goPrevOption && $options.goPrevOption.apply($options, args));
      }, ["prevent","stop"]), ["up"])),
          _cache[4] || (_cache[4] = withKeys(withModifiers(function () {
            var args = [], len = arguments.length;
            while ( len-- ) args[ len ] = arguments[ len ];

            return ($options.selectOption && $options.selectOption.apply($options, args));
      }, ["prevent","stop"]), ["enter"]))
        ]
      }, [
        _hoisted_2$3,
        createElementVNode("div", {
          class: normalizeClass($options.selectTextClasses),
          style: {"overflow-x":"hidden","text-overflow":"ellipsis","white-space":"nowrap"},
          textContent: toDisplayString($options.selectedText)
        }, null, 10 /* CLASS, PROPS */, _hoisted_3$3)
      ], 42 /* CLASS, PROPS, HYDRATE_EVENTS */, _hoisted_1$3)
    ]; }),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["modelValue", "not-close-elements", "append-to-body", "disabled", "style"]))
}

script$6.render = render$6;
script$6.__file = "src/components/select/MultiSelect.vue";

var script$5 = {
  components: { Collapse: Collapse },
  props: {
    modelValue: Boolean,
    fluid: {
      type: Boolean,
      default: true,
    },
    fixedTop: Boolean,
    fixedBottom: Boolean,
    staticTop: Boolean,
    inverse: Boolean,
  },
  emits: ['update:modalValue'],
  data: function data() {
    return {
      show: false,
    }
  },
  computed: {
    navClasses: function navClasses() {
      return {
        navbar: true,
        'navbar-default': !this.inverse,
        'navbar-inverse': this.inverse,
        'navbar-static-top': this.staticTop,
        'navbar-fixed-bottom': this.fixedBottom,
        'navbar-fixed-top': this.fixedTop,
      }
    },
  },
  watch: {
    modelValue: function modelValue(v) {
      this.show = v;
    },
  },
  mounted: function mounted() {
    this.show = !!this.modelValue;
  },
  methods: {
    toggle: function toggle() {
      this.show = !this.show;
      this.$emit('update:modalValue', this.show);
    },
  },
};

var _hoisted_1$2 = { class: "navbar-header" };
var _hoisted_2$2 = /*#__PURE__*/createElementVNode("span", { class: "sr-only" }, "Toggle navigation", -1 /* HOISTED */);
var _hoisted_3$2 = /*#__PURE__*/createElementVNode("span", { class: "icon-bar" }, null, -1 /* HOISTED */);
var _hoisted_4$2 = /*#__PURE__*/createElementVNode("span", { class: "icon-bar" }, null, -1 /* HOISTED */);
var _hoisted_5$1 = /*#__PURE__*/createElementVNode("span", { class: "icon-bar" }, null, -1 /* HOISTED */);
var _hoisted_6$1 = [
  _hoisted_2$2,
  _hoisted_3$2,
  _hoisted_4$2,
  _hoisted_5$1
];

function render$5(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_collapse = resolveComponent("collapse");

  return (openBlock(), createElementBlock("nav", {
    class: normalizeClass($options.navClasses)
  }, [
    createElementVNode("div", {
      class: normalizeClass($props.fluid ? 'container-fluid' : 'container')
    }, [
      createElementVNode("div", _hoisted_1$2, [
        renderSlot(_ctx.$slots, "collapse-btn", {}, function () { return [
          createElementVNode("button", {
            type: "button",
            class: "navbar-toggle collapsed",
            onClick: _cache[0] || (_cache[0] = function () {
              var args = [], len = arguments.length;
              while ( len-- ) args[ len ] = arguments[ len ];

              return ($options.toggle && $options.toggle.apply($options, args));
          })
          }, _hoisted_6$1)
        ]; }),
        renderSlot(_ctx.$slots, "brand")
      ]),
      renderSlot(_ctx.$slots, "default"),
      createVNode(_component_collapse, {
        modelValue: $data.show,
        "onUpdate:modelValue": _cache[1] || (_cache[1] = function ($event) { return (($data.show) = $event); }),
        class: "navbar-collapse"
      }, {
        default: withCtx(function () { return [
          renderSlot(_ctx.$slots, "collapse")
        ]; }),
        _: 3 /* FORWARDED */
      }, 8 /* PROPS */, ["modelValue"])
    ], 2 /* CLASS */)
  ], 2 /* CLASS */))
}

script$5.render = render$5;
script$5.__file = "src/components/navbar/Navbar.vue";

var script$4 = {
  props: {
    left: Boolean,
    right: Boolean,
  },
};

function render$4(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("ul", {
    class: normalizeClass({
      nav: true,
      'navbar-nav': true,
      'navbar-left': $props.left,
      'navbar-right': $props.right,
    })
  }, [
    renderSlot(_ctx.$slots, "default")
  ], 2 /* CLASS */))
}

script$4.render = render$4;
script$4.__file = "src/components/navbar/NavbarNav.vue";

var script$3 = {
  props: {
    left: Boolean,
    right: Boolean,
  },
};

function render$3(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("form", {
    class: normalizeClass({
      'navbar-form': true,
      'navbar-left': $props.left,
      'navbar-right': $props.right,
    })
  }, [
    renderSlot(_ctx.$slots, "default")
  ], 2 /* CLASS */))
}

script$3.render = render$3;
script$3.__file = "src/components/navbar/NavbarForm.vue";

var script$2 = {
  props: {
    left: Boolean,
    right: Boolean,
  },
};

function render$2(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("p", {
    class: normalizeClass({
      'navbar-text': true,
      'navbar-left': $props.left,
      'navbar-right': $props.right,
    })
  }, [
    renderSlot(_ctx.$slots, "default")
  ], 2 /* CLASS */))
}

script$2.render = render$2;
script$2.__file = "src/components/navbar/NavbarText.vue";

var components = /*#__PURE__*/Object.freeze({
  __proto__: null,
  Carousel: script$u,
  Slide: script$t,
  Collapse: Collapse,
  Dropdown: script$s,
  Modal: script$p,
  Tab: script$o,
  Tabs: script$n,
  DatePicker: script$j,
  Affix: script$i,
  Alert: script$h,
  Pagination: script$g,
  Tooltip: script$f,
  Popover: script$e,
  TimePicker: script$d,
  Typeahead: script$c,
  ProgressBar: script$a,
  ProgressBarStack: script$b,
  Breadcrumbs: script$8,
  BreadcrumbItem: script$9,
  Btn: script$q,
  BtnGroup: script$r,
  BtnToolbar: script$7,
  MultiSelect: script$6,
  Navbar: script$5,
  NavbarNav: script$4,
  NavbarForm: script$3,
  NavbarText: script$2
});

var INSTANCE$2 = '_uiv_tooltip_instance';

var bind$2 = function (el, binding) {
  // console.log('bind')
  unbind$2(el);
  var options = [];
  for (var key in binding.modifiers) {
    if (hasOwnProperty(binding.modifiers, key) && binding.modifiers[key]) {
      options.push(key);
    }
  }
  var placement, trigger, enterable;
  options.forEach(function (option) {
    if (/(top)|(left)|(right)|(bottom)/.test(option)) {
      placement = option;
    } else if (/(hover)|(focus)|(click)/.test(option)) {
      trigger = option;
    } else if (/unenterable/.test(option)) {
      enterable = false;
    }
  });

  var vNode = h(script$f, {
    target: el,
    appendTo: binding.arg && '#' + binding.arg,
    text:
      typeof binding.value === 'string'
        ? binding.value && binding.value.toString()
        : binding.value && binding.value.text && binding.value.text.toString(),
    positionBy:
      binding.value &&
      binding.value.positionBy &&
      binding.value.positionBy.toString(),
    viewport:
      binding.value &&
      binding.value.viewport &&
      binding.value.viewport.toString(),
    customClass:
      binding.value &&
      binding.value.customClass &&
      binding.value.customClass.toString(),
    showDelay: binding.value && binding.value.showDelay,
    hideDelay: binding.value && binding.value.hideDelay,
    enterable: enterable,
    placement: placement,
    trigger: trigger,
  });
  var container = document.createElement('div');
  render$s(vNode, container);
  el[INSTANCE$2] = { container: container, vNode: vNode };
};

var unbind$2 = function (el) {
  // console.log('unbind', el[INSTANCE])
  var instance = el[INSTANCE$2];
  if (instance) {
    try {
      removeFromDom(instance.vNode.component.ctx.$refs.popup);
    } catch (_) {}
    render$s(null, instance.container);
  }
  delete el[INSTANCE$2];
};

var update$2 = function (el, binding) {
  // console.log('update', binding.oldValue, '->', binding.value)
  if (binding.value !== binding.oldValue) {
    bind$2(el, binding);
  }
};

var tooltip = { mounted: bind$2, unmounted: unbind$2, updated: update$2 };

var INSTANCE$1 = '_uiv_popover_instance';

var bind$1 = function (el, binding) {
  // console.log('bind')
  unbind$1(el);
  var options = [];
  for (var key in binding.modifiers) {
    if (hasOwnProperty(binding.modifiers, key) && binding.modifiers[key]) {
      options.push(key);
    }
  }
  var placement, trigger, enterable;
  options.forEach(function (option) {
    if (/(top)|(left)|(right)|(bottom)/.test(option)) {
      placement = option;
    } else if (/(hover)|(focus)|(click)/.test(option)) {
      trigger = option;
    } else if (/unenterable/.test(option)) {
      enterable = false;
    }
  });
  var vNode = h(script$e, {
    target: el,
    appendTo: binding.arg && '#' + binding.arg,
    title:
      binding.value && binding.value.title && binding.value.title.toString(),
    positionBy:
      binding.value &&
      binding.value.positionBy &&
      binding.value.positionBy.toString(),
    content:
      binding.value &&
      binding.value.content &&
      binding.value.content.toString(),
    viewport:
      binding.value &&
      binding.value.viewport &&
      binding.value.viewport.toString(),
    customClass:
      binding.value &&
      binding.value.customClass &&
      binding.value.customClass.toString(),
    enterable: enterable,
    placement: placement,
    trigger: trigger,
  });

  var container = document.createElement('div');
  render$s(vNode, container);
  el[INSTANCE$1] = container;
};

var unbind$1 = function (el) {
  // console.log('unbind')
  var instance = el[INSTANCE$1];
  if (instance) {
    render$s(null, instance);
  }
  delete el[INSTANCE$1];
};

var update$1 = function (el, binding) {
  // console.log('update')
  if (binding.value !== binding.oldValue) {
    bind$1(el, binding);
  }
};

var popover = { mounted: bind$1, unmounted: unbind$1, updated: update$1 };

function ScrollSpy(element, target, options) {
  if ( target === void 0 ) target = 'body';
  if ( options === void 0 ) options = {};

  this.el = element;
  this.opts = assign({}, ScrollSpy.DEFAULTS, options);
  this.opts.target = target;
  if (target === 'body') {
    this.scrollElement = window;
  } else {
    this.scrollElement = document.querySelector(("[id=" + target + "]"));
  }
  this.selector = 'li > a';
  this.offsets = [];
  this.targets = [];
  this.activeTarget = null;
  this.scrollHeight = 0;
  if (this.scrollElement) {
    this.refresh();
    this.process();
  }
}

ScrollSpy.DEFAULTS = {
  offset: 10,
  callback: function (ele) { return 0; },
};

ScrollSpy.prototype.getScrollHeight = function () {
  return (
    this.scrollElement.scrollHeight ||
    Math.max(document.body.scrollHeight, document.documentElement.scrollHeight)
  )
};

ScrollSpy.prototype.refresh = function () {
  var this$1$1 = this;

  this.offsets = [];
  this.targets = [];
  this.scrollHeight = this.getScrollHeight();
  var list = nodeListToArray(this.el.querySelectorAll(this.selector));
  var isWindow = this.scrollElement === window;
  list
    .map(function (ele) {
      var href = ele.getAttribute('href');
      if (/^#./.test(href)) {
        var rootEl = isWindow ? document : this$1$1.scrollElement;
        var hrefEl = rootEl.querySelector(("[id='" + (href.slice(1)) + "']"));
        var offset = isWindow
          ? hrefEl.getBoundingClientRect().top
          : hrefEl.offsetTop;
        return [offset, href]
      } else {
        return null
      }
    })
    .filter(function (item) { return item; })
    .sort(function (a, b) { return a[0] - b[0]; })
    .forEach(function (item) {
      this$1$1.offsets.push(item[0]);
      this$1$1.targets.push(item[1]);
    });
  // console.log(this.offsets, this.targets)
};

ScrollSpy.prototype.process = function () {
  var isWindow = this.scrollElement === window;
  var scrollTop =
    (isWindow ? window.pageYOffset : this.scrollElement.scrollTop) +
    this.opts.offset;
  var scrollHeight = this.getScrollHeight();
  var scrollElementHeight = isWindow
    ? getViewportSize().height
    : this.scrollElement.getBoundingClientRect().height;
  var maxScroll = this.opts.offset + scrollHeight - scrollElementHeight;
  var offsets = this.offsets;
  var targets = this.targets;
  var activeTarget = this.activeTarget;
  var i;
  if (this.scrollHeight !== scrollHeight) {
    this.refresh();
  }
  if (scrollTop >= maxScroll) {
    return (
      activeTarget !== (i = targets[targets.length - 1]) && this.activate(i)
    )
  }
  if (activeTarget && scrollTop < offsets[0]) {
    this.activeTarget = null;
    return this.clear()
  }
  for (i = offsets.length; i--; ) {
    activeTarget !== targets[i] &&
      scrollTop >= offsets[i] &&
      (offsets[i + 1] === undefined || scrollTop < offsets[i + 1]) &&
      this.activate(targets[i]);
  }
};

ScrollSpy.prototype.activate = function (target) {
  this.activeTarget = target;
  this.clear();
  var selector =
    this.selector +
    '[data-target="' +
    target +
    '"],' +
    this.selector +
    '[href="' +
    target +
    '"]';
  var activeCallback = this.opts.callback;
  var active = nodeListToArray(this.el.querySelectorAll(selector));
  active.forEach(function (ele) {
    getParents(ele, 'li').forEach(function (item) {
      addClass(item, 'active');
      activeCallback(item);
    });
    if (getParents(ele, '.dropdown-menu').length) {
      addClass(getClosest(ele, 'li.dropdown'), 'active');
    }
  });
};

ScrollSpy.prototype.clear = function () {
  var this$1$1 = this;

  var list = nodeListToArray(this.el.querySelectorAll(this.selector));
  list.forEach(function (ele) {
    getParents(ele, '.active', this$1$1.opts.target).forEach(function (item) {
      removeClass(item, 'active');
    });
  });
};

var INSTANCE = '_uiv_scrollspy_instance';
var events = [EVENTS.RESIZE, EVENTS.SCROLL];

var bind = function (el, binding) {
  // console.log('bind')
  unbind(el);
};

var inserted = function (el, binding) {
  // console.log('inserted')
  var scrollSpy = new ScrollSpy(el, binding.arg, binding.value);
  if (scrollSpy.scrollElement) {
    scrollSpy.handler = function () {
      scrollSpy.process();
    };
    events.forEach(function (event) {
      on(scrollSpy.scrollElement, event, scrollSpy.handler);
    });
  }
  el[INSTANCE] = scrollSpy;
};

var unbind = function (el) {
  // console.log('unbind')
  var instance = el[INSTANCE];
  if (instance && instance.scrollElement) {
    events.forEach(function (event) {
      off(instance.scrollElement, event, instance.handler);
    });
    delete el[INSTANCE];
  }
};

var update = function (el, binding) {
  // console.log('update')
  var isArgUpdated = binding.arg !== binding.oldArg;
  var isValueUpdated = binding.value !== binding.oldValue;
  if (isArgUpdated || isValueUpdated) {
    bind(el);
    inserted(el, binding);
  }
};

var scrollspy = {
  beforeMount: bind,
  unmounted: unbind,
  updated: update,
  mounted: inserted,
};

var directives = /*#__PURE__*/Object.freeze({
  __proto__: null,
  tooltip: tooltip,
  popover: popover,
  scrollspy: scrollspy
});

var TYPES$1 = {
  ALERT: 0,
  CONFIRM: 1,
  PROMPT: 2,
};

var script$1 = {
  components: { Modal: script$p, Btn: script$q },
  mixins: [Local],
  props: {
    backdrop: { type: null, default: undefined },
    title: { type: String, default: undefined },
    content: { type: String, default: undefined },
    html: {
      type: Boolean,
      default: false,
    },
    okText: { type: String, default: undefined },
    okType: {
      type: String,
      default: 'primary',
    },
    cancelText: { type: String, default: undefined },
    cancelType: {
      type: String,
      default: 'default',
    },
    type: {
      type: Number,
      default: TYPES$1.ALERT,
    },
    size: {
      type: String,
      default: 'sm',
    },
    cb: {
      type: Function,
      required: true,
    },
    validator: {
      type: Function,
      default: function () { return null; },
    },
    customClass: { type: null, default: undefined },
    defaultValue: { type: String, default: undefined },
    inputType: {
      type: String,
      default: 'text',
    },
    autoFocus: {
      type: String,
      default: 'ok',
    },
    reverseButtons: {
      type: Boolean,
      default: false,
    },
  },
  data: function data() {
    return {
      TYPES: TYPES$1,
      show: true,
      input: '',
      dirty: false,
    }
  },
  computed: {
    closeOnBackdropClick: function closeOnBackdropClick() {
      // use backdrop prop if exist
      // otherwise, only not available if render as alert
      return isExist(this.backdrop)
        ? Boolean(this.backdrop)
        : this.type !== TYPES$1.ALERT
    },
    inputError: function inputError() {
      return this.validator(this.input)
    },
    inputNotValid: function inputNotValid() {
      return this.dirty && this.inputError
    },
    okBtnText: function okBtnText() {
      return this.okText || this.t('uiv.modal.ok')
    },
    cancelBtnText: function cancelBtnText() {
      return this.cancelText || this.t('uiv.modal.cancel')
    },
  },
  mounted: function mounted() {
    if (this.defaultValue) {
      this.input = this.defaultValue;
    }
  },
  // unmounted() {
  //   console.log('unmounted')
  // },
  methods: {
    toggle: function toggle(show, msg) {
      this.$refs.modal.toggle(show, msg);
    },
    validate: function validate() {
      this.dirty = true;
      if (!isExist(this.inputError)) {
        this.toggle(false, { value: this.input });
      }
    },
  },
};

var _hoisted_1$1 = ["innerHTML"];
var _hoisted_2$1 = { key: 1 };
var _hoisted_3$1 = { key: 2 };
var _hoisted_4$1 = ["type"];

function render$1(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_btn = resolveComponent("btn");
  var _component_modal = resolveComponent("modal");

  return (openBlock(), createBlock(_component_modal, {
    ref: "modal",
    modelValue: $data.show,
    "onUpdate:modelValue": _cache[8] || (_cache[8] = function ($event) { return (($data.show) = $event); }),
    "auto-focus": "",
    size: $props.size,
    title: $props.title,
    header: !!$props.title,
    backdrop: $options.closeOnBackdropClick,
    "cancel-text": $props.cancelText,
    "ok-text": $props.okText,
    class: normalizeClass($props.customClass),
    onHide: $props.cb
  }, createSlots({
    default: withCtx(function () { return [
      ($props.html)
        ? (openBlock(), createElementBlock("div", {
            key: 0,
            innerHTML: $props.content
          }, null, 8 /* PROPS */, _hoisted_1$1))
        : (openBlock(), createElementBlock("p", _hoisted_2$1, toDisplayString($props.content), 1 /* TEXT */)),
      ($props.type === $data.TYPES.PROMPT)
        ? (openBlock(), createElementBlock("div", _hoisted_3$1, [
            createElementVNode("div", {
              class: normalizeClass(["form-group", { 'has-error': $options.inputNotValid }])
            }, [
              withDirectives(createElementVNode("input", {
                ref: "input",
                "onUpdate:modelValue": _cache[0] || (_cache[0] = function ($event) { return (($data.input) = $event); }),
                type: $props.inputType,
                class: "form-control",
                required: "",
                "data-action": "auto-focus",
                onChange: _cache[1] || (_cache[1] = function ($event) { return ($data.dirty = true); }),
                onKeyup: _cache[2] || (_cache[2] = withKeys(function () {
                  var args = [], len = arguments.length;
                  while ( len-- ) args[ len ] = arguments[ len ];

                  return ($options.validate && $options.validate.apply($options, args));
      }, ["enter"]))
              }, null, 40 /* PROPS, HYDRATE_EVENTS */, _hoisted_4$1), [
                [vModelDynamic, $data.input]
              ]),
              withDirectives(createElementVNode("span", { class: "help-block" }, toDisplayString($options.inputError), 513 /* TEXT, NEED_PATCH */), [
                [vShow, $options.inputNotValid]
              ])
            ], 2 /* CLASS */)
          ]))
        : createCommentVNode("v-if", true)
    ]; }),
    _: 2 /* DYNAMIC */
  }, [
    ($props.type === $data.TYPES.ALERT)
      ? {
          name: "footer",
          fn: withCtx(function () { return [
            createVNode(_component_btn, {
              type: $props.okType,
              "data-action": $props.autoFocus === 'ok' ? 'auto-focus' : '',
              onClick: _cache[3] || (_cache[3] = function ($event) { return ($options.toggle(false, 'ok')); }),
              textContent: toDisplayString($options.okBtnText)
            }, null, 8 /* PROPS */, ["type", "data-action", "textContent"])
          ]; })
        }
      : {
          name: "footer",
          fn: withCtx(function () { return [
            ($props.reverseButtons)
              ? (openBlock(), createElementBlock(Fragment, { key: 0 }, [
                  ($props.type === $data.TYPES.CONFIRM)
                    ? (openBlock(), createBlock(_component_btn, {
                        key: 0,
                        type: $props.okType,
                        "data-action": $props.autoFocus === 'ok' ? 'auto-focus' : '',
                        onClick: _cache[4] || (_cache[4] = function ($event) { return ($options.toggle(false, 'ok')); }),
                        textContent: toDisplayString($options.okBtnText)
                      }, null, 8 /* PROPS */, ["type", "data-action", "textContent"]))
                    : (openBlock(), createBlock(_component_btn, {
                        key: 1,
                        type: $props.okType,
                        onClick: $options.validate,
                        textContent: toDisplayString($options.okBtnText)
                      }, null, 8 /* PROPS */, ["type", "onClick", "textContent"])),
                  createVNode(_component_btn, {
                    type: $props.cancelType,
                    "data-action": $props.autoFocus === 'cancel' ? 'auto-focus' : '',
                    onClick: _cache[5] || (_cache[5] = function ($event) { return ($options.toggle(false, 'cancel')); }),
                    textContent: toDisplayString($options.cancelBtnText)
                  }, null, 8 /* PROPS */, ["type", "data-action", "textContent"])
                ], 64 /* STABLE_FRAGMENT */))
              : (openBlock(), createElementBlock(Fragment, { key: 1 }, [
                  createVNode(_component_btn, {
                    type: $props.cancelType,
                    "data-action": $props.autoFocus === 'cancel' ? 'auto-focus' : '',
                    onClick: _cache[6] || (_cache[6] = function ($event) { return ($options.toggle(false, 'cancel')); }),
                    textContent: toDisplayString($options.cancelBtnText)
                  }, null, 8 /* PROPS */, ["type", "data-action", "textContent"]),
                  ($props.type === $data.TYPES.CONFIRM)
                    ? (openBlock(), createBlock(_component_btn, {
                        key: 0,
                        type: $props.okType,
                        "data-action": $props.autoFocus === 'ok' ? 'auto-focus' : '',
                        onClick: _cache[7] || (_cache[7] = function ($event) { return ($options.toggle(false, 'ok')); }),
                        textContent: toDisplayString($options.okBtnText)
                      }, null, 8 /* PROPS */, ["type", "data-action", "textContent"]))
                    : (openBlock(), createBlock(_component_btn, {
                        key: 1,
                        type: $props.okType,
                        onClick: $options.validate,
                        textContent: toDisplayString($options.okBtnText)
                      }, null, 8 /* PROPS */, ["type", "onClick", "textContent"]))
                ], 64 /* STABLE_FRAGMENT */))
          ]; })
        }
  ]), 1032 /* PROPS, DYNAMIC_SLOTS */, ["modelValue", "size", "title", "header", "backdrop", "cancel-text", "ok-text", "class", "onHide"]))
}

script$1.render = render$1;
script$1.__file = "src/components/messagebox/MessageBox.vue";

var destroy$1 = function (container) {
  // console.log('destroyModal')
  render$s(null, container);
};

// handle cancel or ok for confirm & prompt
var shallResolve = function (type, msg) {
  if (type === TYPES$1.CONFIRM) {
    // is confirm
    return msg === 'ok'
  } else {
    // is prompt
    return isExist(msg) && isString(msg.value)
  }
};

var init$1 = function (type, options, cb, resolve, reject) {
  if ( resolve === void 0 ) resolve = null;
  if ( reject === void 0 ) reject = null;

  // const i18n = this.$i18n
  var container = document.createElement('div');
  var vNode = h(script$1, Object.assign({}, {type: type},
    options,
    {cb: function cb$1(msg) {
      destroy$1(container);
      if (isFunction(cb)) {
        if (type === TYPES$1.CONFIRM) {
          shallResolve(type, msg) ? cb(null, msg) : cb(msg);
        } else if (type === TYPES$1.PROMPT) {
          shallResolve(type, msg) ? cb(null, msg.value) : cb(msg);
        } else {
          cb(msg);
        }
      } else if (resolve && reject) {
        if (type === TYPES$1.CONFIRM) {
          shallResolve(type, msg) ? resolve(msg) : reject(msg);
        } else if (type === TYPES$1.PROMPT) {
          shallResolve(type, msg) ? resolve(msg.value) : reject(msg);
        } else {
          resolve(msg);
        }
      }
    }}));
  render$s(vNode, container);
  document.body.appendChild(container.firstElementChild);
};

// eslint-disable-next-line default-param-last
var initModal = function (type, options, cb) {
  var this$1$1 = this;
  if ( options === void 0 ) options = {};

  if (isPromiseSupported()) {
    return new Promise(function (resolve, reject) {
      init$1.apply(this$1$1, [type, options, cb, resolve, reject]);
    })
  } else {
    init$1.apply(this, [type, options, cb]);
  }
};

var alert = function (options, cb) {
  return initModal.apply(this, [TYPES$1.ALERT, options, cb])
};

var confirm = function (options, cb) {
  return initModal.apply(this, [TYPES$1.CONFIRM, options, cb])
};

var prompt = function (options, cb) {
  return initModal.apply(this, [TYPES$1.PROMPT, options, cb])
};

var MessageBox = { alert: alert, confirm: confirm, prompt: prompt };

var TYPES = {
  SUCCESS: 'success',
  INFO: 'info',
  DANGER: 'danger',
  WARNING: 'warning',
};

var PLACEMENTS = {
  TOP_LEFT: 'top-left',
  TOP_RIGHT: 'top-right',
  BOTTOM_LEFT: 'bottom-left',
  BOTTOM_RIGHT: 'bottom-right',
};

var IN_CLASS = 'in';
var ICON = 'glyphicon';
var WIDTH = 300;
var TRANSITION_DURATION = 300;

var script = {
  components: { Alert: script$h },
  props: {
    title: { type: String, default: undefined },
    content: { type: String, default: undefined },
    html: {
      type: Boolean,
      default: false,
    },
    duration: {
      type: Number,
      default: 5000,
    },
    dismissible: {
      type: Boolean,
      default: true,
    },
    type: { type: String, default: undefined },
    placement: { type: String, default: undefined },
    icon: { type: String, default: undefined },
    customClass: { type: null, default: undefined },
    cb: {
      type: Function,
      required: true,
    },
    queue: {
      type: Array,
      required: true,
    },
    offsetY: {
      type: Number,
      default: 15,
    },
    offsetX: {
      type: Number,
      default: 15,
    },
    offset: {
      type: Number,
      default: 15,
    },
  },
  data: function data() {
    return {
      height: 0,
      top: 0,
      horizontal:
        this.placement === PLACEMENTS.TOP_LEFT ||
        this.placement === PLACEMENTS.BOTTOM_LEFT
          ? 'left'
          : 'right',
      vertical:
        this.placement === PLACEMENTS.TOP_LEFT ||
        this.placement === PLACEMENTS.TOP_RIGHT
          ? 'top'
          : 'bottom',
    }
  },
  computed: {
    styles: function styles() {
      var this$1$1 = this;
      var obj;

      var queue = this.queue;
      var thisIndex = queue.findIndex(function (vm) { return vm._.uid === this$1$1._.uid; });
      return ( obj = {
        position: 'fixed'
      }, obj[this.vertical] = ((this.getTotalHeightOfQueue(queue, thisIndex)) + "px"), obj.width = (WIDTH + "px"), obj.transition = ("all " + (TRANSITION_DURATION / 1000) + "s ease-in-out"), obj )
    },
    icons: function icons() {
      if (isString(this.icon)) {
        return this.icon
      }
      switch (this.type) {
        case TYPES.INFO:
        case TYPES.WARNING:
          return (ICON + " " + ICON + "-info-sign")
        case TYPES.SUCCESS:
          return (ICON + " " + ICON + "-ok-sign")
        case TYPES.DANGER:
          return (ICON + " " + ICON + "-remove-sign")
        default:
          return null
      }
    },
  },
  created: function created() {
    // get prev notifications total height in the queue
    this.top = this.getTotalHeightOfQueue(this.queue);
  },
  mounted: function mounted() {
    var this$1$1 = this;

    var el = this.$el;
    el.style[this.vertical] = this.top + 'px';
    this.$nextTick(function () {
      el.style[this$1$1.horizontal] = "-" + WIDTH + "px";
      this$1$1.height = el.offsetHeight;
      el.style[this$1$1.horizontal] = (this$1$1.offsetX) + "px";
      addClass(el, IN_CLASS);
    });
  },
  // unmounted() {
  //   console.log('unmounted')
  // },
  methods: {
    getTotalHeightOfQueue: function getTotalHeightOfQueue(queue, lastIndex) {
      if ( lastIndex === void 0 ) lastIndex = queue.length;

      var totalHeight = this.offsetY;
      for (var i = 0; i < lastIndex; i++) {
        totalHeight += queue[i].height + this.offset;
      }
      return totalHeight
    },
    onDismissed: function onDismissed() {
      removeClass(this.$el, IN_CLASS);
      setTimeout(this.cb, TRANSITION_DURATION);
    },
  },
};

var _hoisted_1 = {
  class: "media",
  style: {"margin":"0"}
};
var _hoisted_2 = {
  key: 0,
  class: "media-left"
};
var _hoisted_3 = { class: "media-body" };
var _hoisted_4 = {
  key: 0,
  class: "media-heading"
};
var _hoisted_5 = ["innerHTML"];
var _hoisted_6 = { key: 2 };

function render(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_alert = resolveComponent("alert");

  return (openBlock(), createBlock(_component_alert, {
    class: normalizeClass(["fade", $props.customClass]),
    style: normalizeStyle($options.styles),
    type: $props.type,
    duration: $props.duration,
    dismissible: $props.dismissible,
    onDismissed: $options.onDismissed
  }, {
    default: withCtx(function () { return [
      createElementVNode("div", _hoisted_1, [
        ($options.icons)
          ? (openBlock(), createElementBlock("div", _hoisted_2, [
              createElementVNode("span", {
                class: normalizeClass($options.icons),
                style: {"font-size":"1.5em"}
              }, null, 2 /* CLASS */)
            ]))
          : createCommentVNode("v-if", true),
        createElementVNode("div", _hoisted_3, [
          ($props.title)
            ? (openBlock(), createElementBlock("div", _hoisted_4, [
                createElementVNode("b", null, toDisplayString($props.title), 1 /* TEXT */)
              ]))
            : createCommentVNode("v-if", true),
          ($props.html)
            ? (openBlock(), createElementBlock("div", {
                key: 1,
                innerHTML: $props.content
              }, null, 8 /* PROPS */, _hoisted_5))
            : (openBlock(), createElementBlock("div", _hoisted_6, toDisplayString($props.content), 1 /* TEXT */))
        ])
      ])
    ]; }),
    _: 1 /* STABLE */
  }, 8 /* PROPS */, ["class", "style", "type", "duration", "dismissible", "onDismissed"]))
}

script.render = render;
script.__file = "src/components/notification/Notification.vue";

var obj;

var queues = reactive(( obj = {}, obj[PLACEMENTS.TOP_LEFT] = [], obj[PLACEMENTS.TOP_RIGHT] = [], obj[PLACEMENTS.BOTTOM_LEFT] = [], obj[PLACEMENTS.BOTTOM_RIGHT] = [], obj ));

var destroy = function (queue, ref) {
  var vNode = ref.vNode;
  var container = ref.container;

  // console.log('destroyNotification')
  render$s(null, container);
  spliceIfExist(queue, vNode.component.ctx);
};

var init = function (options, cb, resolve, reject) {
  if ( resolve === void 0 ) resolve = null;
  if ( reject === void 0 ) reject = null;

  var container = document.createElement('div');
  var placement = options.placement;
  var queue = queues[placement];
  // check if placement is valid
  if (!isExist(queue)) {
    return
  }
  /* istanbul ignore else */
  // `error` alias of `danger`
  if (options.type === 'error') {
    options.type = 'danger';
  }
  var vNode = h(script, Object.assign({}, {queue: queue,
    placement: placement},
    options,
    {cb: function cb$1(msg) {
      destroy(queue, { vNode: vNode, container: container });
      if (isFunction(cb)) {
        cb(msg);
      } else if (resolve && reject) {
        resolve(msg);
      }
    }}));
  render$s(vNode, container);
  document.body.appendChild(container.firstElementChild);
  queue.push(vNode.component.ctx);
};

// eslint-disable-next-line default-param-last
var _notify = function (options, cb) {
  if ( options === void 0 ) options = {};

  // simplify usage: pass string as option.content
  if (isString(options)) {
    options = {
      content: options,
    };
  }
  // set default placement as top-right
  if (!isExist(options.placement)) {
    options.placement = PLACEMENTS.TOP_RIGHT;
  }
  if (isPromiseSupported()) {
    return new Promise(function (resolve, reject) {
      init(options, cb, resolve, reject);
    })
  } else {
    init(options, cb);
  }
};

function _notify2(type, args) {
  if (isString(args)) {
    _notify({
      content: args,
      type: type,
    });
  } else {
    _notify(
      assign({}, args, {
        type: type,
      })
    );
  }
}

var notify = Object.defineProperties(_notify, {
  success: {
    configurable: false,
    writable: false,
    value: function value(args) {
      _notify2('success', args);
    },
  },
  info: {
    configurable: false,
    writable: false,
    value: function value(args) {
      _notify2('info', args);
    },
  },
  warning: {
    configurable: false,
    writable: false,
    value: function value(args) {
      _notify2('warning', args);
    },
  },
  danger: {
    configurable: false,
    writable: false,
    value: function value(args) {
      _notify2('danger', args);
    },
  },
  error: {
    configurable: false,
    writable: false,
    value: function value(args) {
      _notify2('danger', args);
    },
  },
  dismissAll: {
    configurable: false,
    writable: false,
    value: function value() {
      for (var key in queues) {
        /* istanbul ignore else */
        if (hasOwnProperty(queues, key)) {
          queues[key].forEach(function (instance) {
            instance.onDismissed();
          });
        }
      }
    },
  },
});

var Notification = { notify: notify };

var services = /*#__PURE__*/Object.freeze({
  __proto__: null,
  MessageBox: MessageBox,
  Notification: Notification
});

var install = function (app, options) {
  if ( options === void 0 ) options = {};

  // Setup language, en-US for default
  locale.use(options.locale);
  locale.i18n(options.i18n);
  // Register components
  Object.keys(components).forEach(function (key) {
    var _key = options.prefix ? options.prefix + key : key;
    app.component(_key, components[key]);
  });
  // Register directives
  Object.keys(directives).forEach(function (key) {
    var _key = options.prefix ? options.prefix + '-' + key : key;
    app.directive(_key, directives[key]);
  });
  // Register services
  Object.keys(services).forEach(function (key) {
    var service = services[key];
    Object.keys(service).forEach(function (serviceKey) {
      var _key = options.prefix
        ? options.prefix + '_' + serviceKey
        : serviceKey;
      app.config.globalProperties['$' + _key] = service[serviceKey];
    });
  });
};

export { script$i as Affix, script$h as Alert, script$9 as BreadcrumbItem, script$8 as Breadcrumbs, script$q as Btn, script$r as BtnGroup, script$7 as BtnToolbar, script$u as Carousel, Collapse, script$j as DatePicker, script$s as Dropdown, MessageBox, script$p as Modal, script$6 as MultiSelect, script$5 as Navbar, script$3 as NavbarForm, script$4 as NavbarNav, script$2 as NavbarText, Notification, script$g as Pagination, script$e as Popover, script$a as ProgressBar, script$b as ProgressBarStack, script$t as Slide, script$o as Tab, script$n as Tabs, script$d as TimePicker, script$f as Tooltip, script$c as Typeahead, install, popover, scrollspy, tooltip };
//# sourceMappingURL=uiv.esm.js.map
